@@ -1,5 +1,6 @@
 /*
- * $Id$
+ * part of owftpd By Paul H Alfille
+ * The whole is GPLv2 licenced though the ftp code was more liberally licenced when first used.
  */
 
 #include "owftpd.h"
@@ -92,12 +93,13 @@ void FileLexCD(struct cd_parse_s *cps)
 					WildLexCD(cps, oldrest);
 					return;
 				} else {
-					if (oldrest && (strlen(cps->buffer) + strlen(oldrest) + 4 > PATH_MAX)) {
+					if (strlen(cps->buffer) + strlen(oldrest) + 4 > PATH_MAX) {
 						cps->ret = -ENAMETOOLONG;
 						return;
 					}
-					if (cps->buffer[1])
+					if (cps->buffer[1]) {
 						strcat(cps->buffer, "/");
+					}
 					strcat(cps->buffer, oldrest);
 					cps->pse = parse_status_next;
 				}
@@ -111,14 +113,16 @@ void FileLexCD(struct cd_parse_s *cps)
 				cps->ret = -ENAMETOOLONG;
 				return;
 			}
-			if (cps->buffer[1])
+			if (cps->buffer[1]) {
 				strcat(cps->buffer, "/");
+			}
 			strcat(cps->buffer, cps->rest);
 			if (FS_ParsedName(cps->buffer, &pn) == 0) {
 				if (IsDir(&pn)) {
 					++cps->solutions;
-					if (cps->solutions == 1)
+					if (cps->solutions == 1) {
 						cps->dir = strdup(pn.path);
+					}
 				} else {
 					cps->ret = -ENOTDIR;
 				}
@@ -138,8 +142,9 @@ void FileLexCD(struct cd_parse_s *cps)
 			if (FS_ParsedNamePlus(cps->buffer, cps->rest, &pn) == 0) {
 				if (IsDir(&pn)) {
 					++cps->solutions;
-					if (cps->solutions == 1)
+					if (cps->solutions == 1) {
 						cps->dir = strdup(pn.path);
+					}
 				} else {
 					cps->ret = -ENOTDIR;
 				}
@@ -155,6 +160,7 @@ struct wildlexcd {
 	ASCII *match;
 	struct cd_parse_s *cps;
 };
+
 static void WildLexCDCallback(void *v, const struct parsedname *const pn_entry)
 {
 	struct wildlexcd *wlcd = v;
@@ -170,6 +176,7 @@ static void WildLexCDCallback(void *v, const struct parsedname *const pn_entry)
 	cps.pse = parse_status_next;
 	FileLexCD(&cps);
 }
+
 static void WildLexCD(struct cd_parse_s *cps, ASCII * match)
 {
 	struct parsedname pn;
