@@ -1,5 +1,6 @@
 /*
- * $Id$
+ * part of owftpd By Paul H Alfille
+ * The whole is GPLv2 licenced though the ftp code was more liberally licenced when first used.
  */
 
 #include "owftpd.h"
@@ -22,7 +23,7 @@ char *alloca();
 # endif
 #endif
 
-static void fdprintf(int file_descriptor, const char *fmt, ...);
+static void fdprintf(FILE_DESCRIPTOR_OR_ERROR file_descriptor, const char *fmt, ...);
 static void List_show(struct file_parse_s *fps, const struct parsedname *pn);
 static void WildLexParse(struct file_parse_s *fps, ASCII * match);
 static char *skip_ls_options(char *filespec);
@@ -61,26 +62,26 @@ static void List_show(struct file_parse_s *fps, const struct parsedname *pn)
 	};
 	LEVEL_DEBUG("List_show %s", pn->path);
 	switch (fps->fle) {
-	case file_list_list:
-		FS_fstat_postparse(&stbuf, pn);
-		fdprintf(fps->out, "%s%s", stbuf.st_mode & S_IFDIR ? "d" : "-", perms[stbuf.st_mode & 0x07]);
-		/* fps->output link & ownership information */
-		fdprintf(fps->out, " %3d %-8d %-8d %8lu ", stbuf.st_nlink, stbuf.st_uid, stbuf.st_gid, (unsigned long) stbuf.st_size);
-		/* fps->output date */
-		time(&now);
-		localtime_r(&stbuf.st_mtime, &tm_now);
-		age = difftime(now, stbuf.st_mtime);
-		if ((age > 60 * 60 * 24 * 30 * 6)
-			|| (age < -(60 * 60 * 24 * 30 * 6))) {
-			strftime(date_buf, sizeof(date_buf), "%b %e  %Y", &tm_now);
-		} else {
-			strftime(date_buf, sizeof(date_buf), "%b %e %H:%M", &tm_now);
-		}
-		fdprintf(fps->out, "%s ", date_buf);
-		/* Fall Through */
-	case file_list_nlst:
-		/* fps->output filename */
-		fdprintf(fps->out, "%s\r\n", &pn->path[fps->start]);
+		case file_list_list:
+			FS_fstat_postparse(&stbuf, pn);
+			fdprintf(fps->out, "%s%s", stbuf.st_mode & S_IFDIR ? "d" : "-", perms[stbuf.st_mode & 0x07]);
+			/* fps->output link & ownership information */
+			fdprintf(fps->out, " %3d %-8d %-8d %8lu ", stbuf.st_nlink, stbuf.st_uid, stbuf.st_gid, (unsigned long) stbuf.st_size);
+			/* fps->output date */
+			time(&now);
+			localtime_r(&stbuf.st_mtime, &tm_now);
+			age = difftime(now, stbuf.st_mtime);
+			if ((age > 60 * 60 * 24 * 30 * 6)
+				|| (age < -(60 * 60 * 24 * 30 * 6))) {
+				strftime(date_buf, sizeof(date_buf), "%b %e  %Y", &tm_now);
+			} else {
+				strftime(date_buf, sizeof(date_buf), "%b %e %H:%M", &tm_now);
+			}
+			fdprintf(fps->out, "%s ", date_buf);
+			/* Fall Through */
+		case file_list_nlst:
+			/* fps->output filename */
+			fdprintf(fps->out, "%s\r\n", &pn->path[fps->start]);
 	}
 }
 
@@ -95,8 +96,9 @@ void FileLexParse(struct file_parse_s *fps)
 			/* trailing / only at root */
 			fps->ret = 0;
 			fps->start = strlen(fps->buffer);
-			if (fps->start > 1)
+			if (fps->start > 1) {
 				++fps->start;
+			}
 			fps->rest = skip_ls_options(fps->rest);
 			if (fps->rest == NULL || fps->rest[0] == '\0') {
 				fps->pse = parse_status_tame;
@@ -156,12 +158,13 @@ void FileLexParse(struct file_parse_s *fps)
 					WildLexParse(fps, oldrest);
 					return;
 				} else {
-					if (oldrest && (strlen(fps->buffer) + strlen(oldrest) + 4 > PATH_MAX)) {
+					if (strlen(fps->buffer) + strlen(oldrest) + 4 > PATH_MAX) {
 						fps->ret = -ENAMETOOLONG;
 						return;
 					}
-					if (fps->buffer[1])
+					if (fps->buffer[1]) {
 						strcat(fps->buffer, "/");
+					}
 					strcat(fps->buffer, oldrest);
 					fps->pse = parse_status_next;
 				}
@@ -171,13 +174,16 @@ void FileLexParse(struct file_parse_s *fps)
 			LEVEL_DEBUG("FTP parse_status_tame Path<%s> File <%s>", fps->buffer, fps->rest);
 			/* fps->buffer is absolute */
 			/* trailing / only at root */
-			if (fps->rest && (strlen(fps->buffer) + strlen(fps->rest) + 4 > PATH_MAX)) {
-				fps->ret = -ENAMETOOLONG;
-				return;
+			if ( fps-> rest != NULL ) {
+				if ( strlen(fps->buffer) + strlen(fps->rest) + 4 > PATH_MAX ) {
+					fps->ret = -ENAMETOOLONG;
+					return;
+				}
+				if ( fps->buffer[1] != 0 ) {
+					strcat(fps->buffer, "/");
+				}
+				strcat(fps->buffer, fps->rest);
 			}
-			if (fps->buffer[1])
-				strcat(fps->buffer, "/");
-			strcat(fps->buffer, fps->rest);
 			if (FS_ParsedName(fps->buffer, &pn) == 0) {
 				if (IsDir(&pn)) {
 					fps->start = strlen(fps->buffer) + 1;
@@ -270,12 +276,14 @@ static void WildLexParse(struct file_parse_s *fps, ASCII * match)
 
 		wlp.end = &fps->buffer[strlen(fps->buffer)];
 
-		if (root)
+		if (root) {
 			--wlp.end;
+		}
 		wlp.end[0] = '/';
 		FS_dir(WildLexParseCallback, &wlp, &pn);
-		if (root)
+		if (root) {
 			++wlp.end;
+		}
 		wlp.end[0] = '\0';		// restore fps->buffer
 	}
 	FS_ParsedName_destroy(&pn);
@@ -283,7 +291,7 @@ static void WildLexParse(struct file_parse_s *fps, ASCII * match)
 }
 
 /* write with care for max length and incomplete outout */
-static void fdprintf(int file_descriptor, const char *fmt, ...)
+static void fdprintf(FILE_DESCRIPTOR_OR_ERROR file_descriptor, const char *fmt, ...)
 {
 	char buf[PATH_MAX + 1];
 	ssize_t buflen;
@@ -291,7 +299,7 @@ static void fdprintf(int file_descriptor, const char *fmt, ...)
 	int amt_written;
 	int write_ret;
 
-	daemon_assert(file_descriptor >= 0);
+	daemon_assert(FILE_DESCRIPTOR_VALID(file_descriptor));
 	daemon_assert(fmt != NULL);
 
 	va_start(ap, fmt);
