@@ -1,5 +1,7 @@
 /*
- * $Id$
+ * Part of owftp by Paul Alfille
+ * although this source was (legally) culled from open source
+ * the whole is GPLv2 licenced
  */
 
 #include "owftpd.h"
@@ -23,32 +25,31 @@ struct {
 	char *name;
 	int arg_type;
 } command_def[] = {
-	{
-	"USER", ARG_STRING}, {
-	"PASS", ARG_STRING}, {
-	"CWD", ARG_STRING}, {
-	"CDUP", ARG_NONE}, {
-	"QUIT", ARG_NONE}, {
-	"PORT", ARG_HOST_PORT}, {
-	"LPRT", ARG_HOST_PORT_LONG}, {
-	"EPRT", ARG_HOST_PORT_EXT}, {
-	"PASV", ARG_NONE}, {
-	"LPSV", ARG_NONE}, {
-	"EPSV", ARG_OPTIONAL_NUMBER}, {
-	"TYPE", ARG_TYPE}, {
-	"STRU", ARG_STRUCTURE}, {
-	"MODE", ARG_MODE}, {
-	"RETR", ARG_STRING}, {
-	"STOR", ARG_STRING}, {
-	"PWD", ARG_NONE}, {
-	"LIST", ARG_OPTIONAL_STRING}, {
-	"NLST", ARG_OPTIONAL_STRING}, {
-	"SYST", ARG_NONE}, {
-	"HELP", ARG_OPTIONAL_STRING}, {
-	"NOOP", ARG_NONE}, {
-	"REST", ARG_OFFSET}, {
-	"SIZE", ARG_STRING}, {
-	"MDTM", ARG_STRING}
+	{ "USER", ARG_STRING},
+	{ "PASS", ARG_STRING},
+	{ "CWD",  ARG_STRING},
+	{ "CDUP", ARG_NONE},
+	{ "QUIT", ARG_NONE},
+	{ "PORT", ARG_HOST_PORT},
+	{ "LPRT", ARG_HOST_PORT_LONG},
+	{ "EPRT", ARG_HOST_PORT_EXT},
+	{ "PASV", ARG_NONE},
+	{ "LPSV", ARG_NONE},
+	{ "EPSV", ARG_OPTIONAL_NUMBER},
+	{ "TYPE", ARG_TYPE},
+	{ "STRU", ARG_STRUCTURE},
+	{ "MODE", ARG_MODE},
+	{ "RETR", ARG_STRING},
+	{ "STOR", ARG_STRING},
+	{ "PWD",  ARG_NONE},
+	{ "LIST", ARG_OPTIONAL_STRING},
+	{ "NLST", ARG_OPTIONAL_STRING},
+	{ "SYST", ARG_NONE},
+	{ "HELP", ARG_OPTIONAL_STRING},
+	{ "NOOP", ARG_NONE},
+	{ "REST", ARG_OFFSET},
+	{ "SIZE", ARG_STRING},
+	{ "MDTM", ARG_STRING},
 };
 
 #define NUM_COMMAND (sizeof(command_def) / sizeof(command_def[0]))
@@ -64,48 +65,52 @@ static const char *parse_host_port_ext(sockaddr_storage_t * sa, const char *s);
 int ftp_command_parse(const char *input, struct ftp_command_s *cmd)
 {
 	size_t match;
-	struct ftp_command_s tmp;
 	int c;
 	const char *optional_number;
 
-	if (input == NULL || cmd == NULL)
+	if (input == NULL || cmd == NULL) {	
 		return 0;
+	}
 
 	/* see if our input starts with a valid command */
-	for (match = 0; match < NUM_COMMAND; ++match) {
-		if (strncasecmp(input, command_def[match].name, strlen(command_def[match].name)) == 0)
+	for (match = 0; match < NUM_COMMAND; ++match) { // loop though known commands
+		if (strncasecmp(input, command_def[match].name, strlen(command_def[match].name)) == 0) {
+			/* copy our command */
+			strcpy(cmd->command, command_def[match].name);
+
+			/* advance input past the command */
+			input += strlen(command_def[match].name);
 			break;
+		}
 	}
 
 	/* if we didn't find a match, return error */
-	if (match == NUM_COMMAND)
+	if (match == NUM_COMMAND) {
 		return 0;
+	}
 
-	/* copy our command */
-	strcpy(tmp.command, command_def[match].name);
-
-	/* advance input past the command */
-	input += strlen(command_def[match].name);
 
 	/* now act based on the command */
 	switch (command_def[match].arg_type) {
 	case ARG_NONE:
-		tmp.num_arg = 0;
+		cmd->num_arg = 0;
 		break;
 	case ARG_STRING:
-		if (*input != ' ')
+		if (*input != ' ') {
+			// no space before arguments
 			return 0;
+		}
 		++input;
-		input = copy_string(tmp.arg[0].string, input);
-		tmp.num_arg = 1;
+		input = copy_string(cmd->arg[0].string, input);
+		cmd->num_arg = 1;
 		break;
 	case ARG_OPTIONAL_STRING:
 		if (*input == ' ') {
 			++input;
-			input = copy_string(tmp.arg[0].string, input);
-			tmp.num_arg = 1;
+			input = copy_string(cmd->arg[0].string, input);
+			cmd->num_arg = 1;
 		} else {
-			tmp.num_arg = 0;
+			cmd->num_arg = 0;
 		}
 		break;
 	case ARG_HOST_PORT:
@@ -114,49 +119,54 @@ int ftp_command_parse(const char *input, struct ftp_command_s *cmd)
 		}
 		input++;
 		/* parse the host & port information (if any) */
-		input = parse_host_port(&tmp.arg[0].host_port, input);
-		if (input == NULL)
+		input = parse_host_port(&cmd->arg[0].host_port, input);
+		if (input == NULL) {
 			return 0;
-		tmp.num_arg = 1;
+		}
+		cmd->num_arg = 1;
 		break;
 	case ARG_HOST_PORT_LONG:
-		if (*input != ' ')
+		if (*input != ' ') {
 			return 0;
+		}
 		input++;
 		/* parse the host & port information (if any) */
-		input = parse_host_port_long(&tmp.arg[0].host_port, input);
-		if (input == NULL)
+		input = parse_host_port_long(&cmd->arg[0].host_port, input);
+		if (input == NULL) {
 			return 0;
-		tmp.num_arg = 1;
+		}
+		cmd->num_arg = 1;
 		break;
 	case ARG_HOST_PORT_EXT:
-		if (*input != ' ')
+		if (*input != ' ') {
 			return 0;
+		}
 		input++;
 		/* parse the host & port information (if any) */
-		input = parse_host_port_ext(&tmp.arg[0].host_port, input);
-		if (input == NULL)
+		input = parse_host_port_ext(&cmd->arg[0].host_port, input);
+		if (input == NULL) {
 			return 0;
-		tmp.num_arg = 1;
+		}
+		cmd->num_arg = 1;
 		break;
 		/* the optional number may also be "ALL" */
 	case ARG_OPTIONAL_NUMBER:
 		if (*input == ' ') {
 			++input;
-			optional_number = parse_number(&tmp.arg[0].num, input, 255);
+			optional_number = parse_number(&cmd->arg[0].num, input, 255);
 			if (optional_number != NULL) {
 				input = optional_number;
 			} else {
-				if ((tolower(input[0]) == 'a') && (tolower(input[1]) == 'l') && (tolower(input[2]) == 'l')) {
-					tmp.arg[0].num = EPSV_ALL;
+				if ((tolower( (int) input[0] ) == 'a') && (tolower( (int) input[1] ) == 'l') && (tolower( (int) input[2] ) == 'l')) {
+					cmd->arg[0].num = EPSV_ALL;
 					input += 3;
 				} else {
 					return 0;
 				}
 			}
-			tmp.num_arg = 1;
+			cmd->num_arg = 1;
 		} else {
-			tmp.num_arg = 0;
+			cmd->num_arg = 0;
 		}
 		break;
 	case ARG_TYPE:
@@ -164,36 +174,37 @@ int ftp_command_parse(const char *input, struct ftp_command_s *cmd)
 			return 0;
 		}
 		input++;
-		c = toupper(*input);
+		c = toupper( (int) input[0] );
 		if ((c == 'A') || (c == 'E')) {
-			tmp.arg[0].string[0] = c;
-			tmp.arg[0].string[1] = '\0';
+			cmd->arg[0].string[0] = c;
+			cmd->arg[0].string[1] = '\0';
 			input++;
 			if (*input == ' ') {
 				input++;
-				c = toupper(*input);
+				c = toupper( (int) input[0] );
 				if ((c != 'N') && (c != 'T') && (c != 'C'))
 					return 0;
-				tmp.arg[1].string[0] = c;
-				tmp.arg[1].string[1] = '\0';
+				cmd->arg[1].string[0] = c;
+				cmd->arg[1].string[1] = '\0';
 				input++;
-				tmp.num_arg = 2;
+				cmd->num_arg = 2;
 			} else {
-				tmp.num_arg = 1;
+				cmd->num_arg = 1;
 			}
 		} else if (c == 'I') {
-			tmp.arg[0].string[0] = 'I';
-			tmp.arg[0].string[1] = '\0';
+			cmd->arg[0].string[0] = 'I';
+			cmd->arg[0].string[1] = '\0';
 			input++;
-			tmp.num_arg = 1;
+			cmd->num_arg = 1;
 		} else if (c == 'L') {
-			tmp.arg[0].string[0] = 'L';
-			tmp.arg[0].string[1] = '\0';
+			cmd->arg[0].string[0] = 'L';
+			cmd->arg[0].string[1] = '\0';
 			input++;
-			input = parse_number(&tmp.arg[1].num, input, 255);
-			if (input == NULL)
+			input = parse_number(&cmd->arg[1].num, input, 255);
+			if (input == NULL) {
 				return 0;
-			tmp.num_arg = 2;
+			}
+			cmd->num_arg = 2;
 		} else {
 			return 0;
 		}
@@ -202,45 +213,50 @@ int ftp_command_parse(const char *input, struct ftp_command_s *cmd)
 		if (*input != ' ')
 			return 0;
 		input++;
-		c = toupper(*input);
-		if ((c != 'F') && (c != 'R') && (c != 'P'))
+		c = toupper( (int) input[0] );
+		if ((c != 'F') && (c != 'R') && (c != 'P')) {
 			return 0;
+		}
 		input++;
-		tmp.arg[0].string[0] = c;
-		tmp.arg[0].string[1] = '\0';
-		tmp.num_arg = 1;
+		cmd->arg[0].string[0] = c;
+		cmd->arg[0].string[1] = '\0';
+		cmd->num_arg = 1;
 		break;
 	case ARG_MODE:
-		if (*input != ' ')
+		if (*input != ' ') {
 			return 0;
+		}
 		input++;
-		c = toupper(*input);
-		if ((c != 'S') && (c != 'B') && (c != 'C'))
+		c = toupper( (int) input[0] );
+		if ((c != 'S') && (c != 'B') && (c != 'C')) {
 			return 0;
+		}
 		input++;
-		tmp.arg[0].string[0] = c;
-		tmp.arg[0].string[1] = '\0';
-		tmp.num_arg = 1;
+		cmd->arg[0].string[0] = c;
+		cmd->arg[0].string[1] = '\0';
+		cmd->num_arg = 1;
 		break;
 	case ARG_OFFSET:
-		if (*input != ' ')
+		if (*input != ' ') {
 			return 0;
+		}
 		input++;
-		input = parse_offset(&tmp.arg[0].offset, input);
-		if (input == NULL)
+		input = parse_offset(&cmd->arg[0].offset, input);
+		if (input == NULL) {
 			return 0;
-		tmp.num_arg = 1;
+		}
+		cmd->num_arg = 1;
 		break;
 	default:
 		daemon_assert(0);
 	}
 
 	/* check for our ending newline */
-	if (*input != '\n')
+	if (*input != '\n') {
 		return 0;
+	}
 
 	/* return our result */
-	*cmd = tmp;
 	return 1;
 }
 
@@ -275,17 +291,20 @@ static const char *parse_host_port(struct sockaddr_in *addr, const char *s)
 	/* scan in 5 pairs of "#," */
 	for (i = 0; i < 5; i++) {
 		s = parse_number(&octets[i], s, 255);
-		if (s == NULL)
+		if (s == NULL) {
 			return NULL;
-		if (*s != ',')
+		}
+		if (*s != ',') {
 			return NULL;
+		}
 		s++;
 	}
 
 	/* scan in ending "#" */
 	s = parse_number(&octets[5], s, 255);
-	if (s == NULL)
+	if (s == NULL) {
 		return NULL;
+	}
 
 	daemon_assert(octets[0] >= 0);
 	daemon_assert(octets[0] <= 255);
@@ -334,7 +353,7 @@ static const char *parse_host_port_long(sockaddr_storage_t * sa, const char *s)
 	if (s == NULL) {
 		return NULL;
 	}
-	if (*s != ',') {
+	if (s[0] != ',') {
 		return NULL;
 	}
 	s++;
@@ -344,7 +363,7 @@ static const char *parse_host_port_long(sockaddr_storage_t * sa, const char *s)
 	if (s == NULL) {
 		return NULL;
 	}
-	if (*s != ',') {
+	if (s[0] != ',') {
 		return NULL;
 	}
 	s++;
@@ -357,7 +376,7 @@ static const char *parse_host_port_long(sockaddr_storage_t * sa, const char *s)
 		if (s == NULL) {
 			return NULL;
 		}
-		if (*s != ',') {
+		if (s[0] != ',') {
 			return NULL;
 		}
 		s++;
@@ -365,13 +384,13 @@ static const char *parse_host_port_long(sockaddr_storage_t * sa, const char *s)
 
 	/* parse port length */
 	s = parse_number(&port_len, s, 255);
-	if (s == NULL) {
-		return NULL;
-	}
 
 	/* parse port */
 	for (i = 0; i < port_len; i++) {
-		if (*s != ',') {
+		if (s == NULL) {
+			return NULL;
+		}
+		if (s[0] != ',') {
 			return NULL;
 		}
 		s++;
@@ -391,9 +410,8 @@ static const char *parse_host_port_long(sockaddr_storage_t * sa, const char *s)
 		}
 		memcpy(&SINADDR(sa), addr, addr_len);
 		SINPORT(sa) = htons((port[0] << 8) + port[1]);
-	}
 #ifdef INET6
-	else if (family == 6) {
+	} else if (family == 6) {
 		SAFAM(sa) = AF_INET6;
 		if (addr_len != sizeof(struct in6_addr)) {
 			return NULL;
@@ -403,9 +421,8 @@ static const char *parse_host_port_long(sockaddr_storage_t * sa, const char *s)
 		}
 		memcpy(&SIN6ADDR(sa), addr, addr_len);
 		SINPORT(sa) = htons((port[0] << 8) + port[1]);
-	}
 #endif
-	else {
+	} else {
 		SAFAM(sa) = -1;
 	}
 
@@ -432,13 +449,11 @@ static const char *parse_host_port_ext(sockaddr_storage_t * sa, const char *s)
 	/* get address family */
 	if (*s == '1') {
 		family = AF_INET;
-	}
 #ifdef INET6
-	else if (*s == '2') {
+	} else if (*s == '2') {
 		family = AF_INET6;
-	}
 #endif
-	else {
+	} else {
 		return NULL;
 	}
 	s++;
@@ -526,14 +541,14 @@ static const char *parse_number(int *num, const char *s, int max_num)
 	daemon_assert(num != NULL);
 
 	/* handle first character */
-	if (!isdigit(*s)) {
+	if (!isdigit( (int) s[0] )) {
 		return NULL;
 	}
 	tmp = (*s - '0');
 	s++;
 
 	/* handle subsequent characters */
-	while (isdigit(*s)) {
+	while (isdigit( (int) s[0] )) {
 		cur_digit = (*s - '0');
 
 		/* check for overflow */
@@ -576,14 +591,14 @@ static const char *parse_offset(off_t * ofs, const char *s)
 	daemon_assert(max_ofs != 0);
 
 	/* handle first character */
-	if (!isdigit(*s)) {
+	if (!isdigit( (int) s[0] )) {
 		return NULL;
 	}
 	tmp_ofs = (*s - '0');
 	s++;
 
 	/* handle subsequent characters */
-	while (isdigit(*s)) {
+	while (isdigit( (int) s[0] )) {
 		cur_digit = (*s - '0');
 
 		/* check for overflow */
