@@ -1,5 +1,8 @@
 /*
- * $Id$
+ * owftpd -- an ftp server for owfs 1-wire "virtual" files.
+ * No actual file contents are exposed.
+ * see owfs.org
+ * Paul Alfille -- GPLv2
  */
 
 #include "owftpd.h"
@@ -11,14 +14,20 @@ int main(int argc, char *argv[])
 	int err, signo;
 	struct ftp_listener_s ftp_listener;
 	sigset_t myset;
+	
+	struct re_exec sre =
+	{
+		& ftp_listener, 
+		ftp_listener_stop, 
+	};
 
 	/* Set up owlib */
 	LibSetup(program_type_ftpd);
+	Setup_Systemd() ; // systemd?
+	Setup_Launchd() ; // launchd?
 
 	/* grab our executable name */
-	if (argc > 0) {
-		Globals.progname = strdup(argv[0]);
-	}
+	ArgCopy( argc, argv ) ;
 
 	/* check our command-line arguments */
 	while ((c = getopt_long(argc, argv, OWLIB_OPT, owopts_long, NULL)) != -1) {
@@ -35,6 +44,7 @@ int main(int argc, char *argv[])
 	/* FTP on default port? */
 	if (Outbound_Control.active == 0) {
 		ARG_Server(NULL);	// default or ephemeral port
+		// except systemd
 	}
 
 	/* non-option args are adapters */
@@ -55,8 +65,8 @@ int main(int argc, char *argv[])
 	// SIGTERM is used to kill all outprocesses which hang in accept()
 	pthread_sigmask(SIG_BLOCK, &myset, NULL);
 
-	/* Set up adapters */
-	if ( BAD(LibStart()) ) {
+	/* Set up adapters and systemd */
+	if ( BAD(LibStart(&sre)) ) {
 		ow_exit(1);
 	}
 
@@ -81,6 +91,7 @@ int main(int argc, char *argv[])
 	sigaddset(&myset, SIGTERM);
 
 	while (!StateInfo.shutting_down) {
+		Announce_Systemd() ; // If in systemd mode announce we're ready.
 		if ((err = sigwait(&myset, &signo)) == 0) {
 			if (signo == SIGHUP) {
 				LEVEL_DEBUG("owftpd: ignore signo=%d", signo);
