@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -103,7 +102,7 @@ init_exit:
 static GOOD_OR_BAD setup_from_commandline( const char *command_line )
 {
 	RETURN_BAD_IF_BAD( owopt_packed(command_line) ) ;
-	RETURN_BAD_IF_BAD( LibStart() );
+	RETURN_BAD_IF_BAD( LibStart(NULL) );
 	StateInfo.owlib_state = lib_state_started;
 	return gbGOOD ;
 }	
@@ -111,9 +110,7 @@ static GOOD_OR_BAD setup_from_commandline( const char *command_line )
 static GOOD_OR_BAD setup_from_args( int argc, char **argv )
 {
 	/* grab our executable name */
-	if (argc > 0) {
-		Globals.progname = owstrdup(argv[0]);
-	}
+	ArgCopy( argc, argv ) ;
 
 	// process the command line flags
 	do {
@@ -154,6 +151,7 @@ GOOD_OR_BAD API_init_args(int argc, char **argv, enum restart_init repeat)
 		StateInfo.owlib_state = lib_state_setup;
 	}
 	// now restart
+	ArgCopy( argc, argv ) ;
 	if (StateInfo.owlib_state == lib_state_setup) {
 		return_code = setup_from_args( argc, argv ) ;
 	}
