@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -9,31 +8,41 @@ $Id$
     1wire/iButton system from Dallas Semiconductor
 */
 
+// regex
+
 /* ow_opt -- owlib specific command line options processing */
 
 #include <config.h>
 #include "owfs_config.h"
 #include "ow.h"
 #include "ow_connection.h"
+#include "ow_usb_msg.h" // for DS9490_port_setup
 
-enum arg_address { arg_addr_device, arg_addr_null, arg_addr_ip, arg_addr_colon, arg_addr_number, arg_addr_other } ;
+enum arg_address { arg_addr_device, arg_addr_null, arg_addr_ip, arg_addr_colon, arg_addr_number, arg_addr_other, arg_addr_error, } ;
 
 static enum arg_address ArgType( const char * arg )
 {
+	static regex_t rx_dev ;
+	static regex_t rx_num ;
+	static regex_t rx_ip ;
+	static regex_t rx_col ;
+	
+	// compile regex expressions
+	ow_regcomp( &rx_dev, "/", REG_NOSUB ) ;
+	ow_regcomp( &rx_num, "^[:digit:]+$", REG_NOSUB ) ;
+	ow_regcomp( &rx_ip, "[:digit:]{1,3}\\.[:digit:]{1,3}\\.[:digit:]{1,3}\\.[:digit:]{1,3}", REG_NOSUB ) ;
+	ow_regcomp( &rx_col, ":", REG_NOSUB ) ;
+
 	if ( arg == NULL ) {
 		return arg_addr_null ;
-	} else if ( strchr( arg, '/' ) ) {
-		return arg_addr_device ;
-	} else if ( strchr( arg, ':' ) ) {
-		return arg_addr_colon ;
-	} else if ( strspn( arg, "0123456789" ) == strlen(arg) ) {
-		return arg_addr_number ;
-	} else if ( strchr(                     arg,                      '.' )
-		&&  strchr( strchr(                 arg,               '.' ), '.' )
-		&&  strchr( strchr( strchr(         arg,        '.' ), '.' ), '.' )
-		&&  strchr( strchr( strchr( strchr( arg, '.' ), '.' ), '.' ), '.' )
-		) {
+	} else if ( ow_regexec( &rx_ip, arg, NULL ) == 0 ) {
 		return arg_addr_ip ;
+	} else if ( ow_regexec( &rx_col, arg, NULL ) == 0 ) {
+		return arg_addr_colon ;
+	} else if ( ow_regexec( &rx_dev, arg, NULL ) == 0 ) {
+		return arg_addr_device ;
+	} else if ( ow_regexec( &rx_num, arg, NULL ) == 0 ) {
+		return arg_addr_number ;
 	}
 	return arg_addr_other ;
 }
@@ -55,6 +64,7 @@ static GOOD_OR_BAD Serial_or_telnet( const char * arg, struct connection_in * in
 {
 	switch( ArgType(arg) ) {
 		case arg_addr_null:
+		case arg_addr_error:
 			LEVEL_DEFAULT("Error with device. Specify a serial port, or a serial-over-telnet network address");
 			return gbBAD ;
 		case arg_addr_device:
@@ -238,6 +248,38 @@ GOOD_OR_BAD ARG_HA7E(const char *arg)
 	return Serial_or_telnet( arg, in ) ;
 }
 
+GOOD_OR_BAD ARG_DS1WM(const char *arg)
+{
+	struct port_in * pin = NewPort( NULL ) ;
+	struct connection_in * in ;
+	if ( pin == NULL ) {
+		return gbBAD;
+	}
+	in = pin->first ;
+	if (in == NO_CONNECTION) {
+		return gbBAD;
+	}
+	arg_data(arg,pin) ;
+	pin->busmode = bus_ds1wm ;
+	return gbGOOD ;
+}
+
+GOOD_OR_BAD ARG_K1WM(const char *arg)
+{
+	struct port_in * pin = NewPort( NULL ) ;
+	struct connection_in * in ;
+	if ( pin == NULL ) {
+		return gbBAD;
+	}
+	in = pin->first ;
+	if (in == NO_CONNECTION) {
+		return gbBAD;
+	}
+	arg_data(arg,pin) ;
+	pin->busmode = bus_k1wm ;
+	return gbGOOD ;
+}
+
 GOOD_OR_BAD ARG_ENET(const char *arg)
 {
 	struct port_in * pin = NewPort( NULL ) ;
@@ -291,6 +333,22 @@ GOOD_OR_BAD ARG_Link(const char *arg)
 	return Serial_or_telnet( arg, in ) ;
 }
 
+GOOD_OR_BAD ARG_MasterHub(const char *arg)
+{
+	struct port_in * pin = NewPort( NULL ) ;
+	struct connection_in * in ;
+	if ( pin == NULL ) {
+		return gbBAD;
+	}
+	in = pin->first ;
+	if (in == NO_CONNECTION) {
+		return gbBAD;
+	}
+	arg_data(arg,pin) ;
+	pin->busmode = bus_masterhub ; // link
+	return Serial_or_telnet( arg, in ) ;
+}
+
 GOOD_OR_BAD ARG_Mock(const char *arg)
 {
 	struct port_in * pin = NewPort( NULL ) ;
@@ -323,30 +381,8 @@ GOOD_OR_BAD ARG_W1_monitor(void)
 	return gbGOOD;
 }
 
-GOOD_OR_BAD ARG_USB_monitor(const char *arg)
-{
-#if OW_USB
-	struct port_in * pin = NewPort( NULL ) ;
-	struct connection_in * in ;
-	if ( pin == NULL ) {
-		return gbBAD;
-	}
-	in = pin->first ;
-	if (in == NO_CONNECTION) {
-		return gbBAD;
-	}
-	arg_data(arg,pin) ;
-	pin->busmode = bus_usb_monitor;
-	return gbGOOD;
-#else
-	fprintf(stderr, "OWFS is compiled without USB support.\n");
-	return gbBAD;
-#endif
-}
-
 GOOD_OR_BAD ARG_Browse(void)
 {
-#if OW_ZERO
 	struct port_in * pin = NewPort( NULL ) ;
 	struct connection_in * in ;
 	if ( pin == NULL ) {
@@ -359,10 +395,6 @@ GOOD_OR_BAD ARG_Browse(void)
 	arg_data("ZeroConf monitor",pin) ;
 	pin->busmode = bus_browse;
 	return gbGOOD;
-#else
-	fprintf(stderr, "OWFS is compiled without Zeroconf/Bonjour support.\n");
-	return gbBAD;
-#endif
 }
 
 // This is to connect to owserver as a (remote) bus
@@ -384,6 +416,7 @@ GOOD_OR_BAD ARG_Net(const char *arg)
 
 GOOD_OR_BAD ARG_Parallel(const char *arg)
 {
+	(void) arg ;
 #if OW_PARPORT
 	struct port_in * pin = NewPort( NULL ) ;
 	struct connection_in * in ;
@@ -438,13 +471,24 @@ GOOD_OR_BAD ARG_Serial(const char *arg)
 }
 
 // This is owserver's listening port
+// and owfs's mountpoint
 GOOD_OR_BAD ARG_Server(const char *arg)
 {
-	struct connection_out *out = NewOut();
-	if (out == NULL) {
-		return gbBAD;
-	}
-	out->name = (arg!=NULL) ? owstrdup(arg) : NULL;
+	switch (Globals.daemon_status) {
+		case e_daemon_sd:
+		case e_daemon_sd_done:
+			LEVEL_DEBUG("Systemd mode: Ignore %s",arg);
+			break ;
+		default:
+		{
+			struct connection_out *out = NewOut();
+			if (out == NULL) {
+				return gbBAD;
+			}
+			out->name = (arg!=NULL) ? owstrdup(arg) : NULL;
+		}
+			break ;
+	}		
 	return gbGOOD;
 }
 
@@ -468,19 +512,26 @@ GOOD_OR_BAD ARG_Tester(const char *arg)
 GOOD_OR_BAD ARG_USB(const char *arg)
 {
 #if OW_USB
-	struct port_in * pin = NewPort( NULL ) ;
-	struct connection_in * in ;
-	if ( pin == NULL ) {
-		return gbBAD;
+	if ( Globals.luc != NULL ) {
+		struct port_in * pin = NewPort( NULL ) ;
+		struct connection_in * in ;
+		if ( pin == NULL ) {
+			return gbBAD;
+		}
+		in = pin->first ;
+		if (in == NO_CONNECTION) {
+			return gbBAD;
+		}
+		pin->busmode = bus_usb;
+		DS9490_port_setup( NULL, pin ) ; // flag as not yet set up
+		arg_data(arg,pin) ;
+		return gbGOOD;
+	} else {
+		LEVEL_DEFAULT( "USB library initialization had problems -- can't proceed") ;
+		return gbBAD ;
 	}
-	in = pin->first ;
-	if (in == NO_CONNECTION) {
-		return gbBAD;
-	}
-	pin->busmode = bus_usb;
-	arg_data(arg,pin) ;
-	return gbGOOD;
 #else							/* OW_USB */
+	(void) arg ;
 	LEVEL_DEFAULT("USB support (intentionally) not included in compilation. Check LIBUSB, then reconfigure and recompile.");
 	return gbBAD;
 #endif							/* OW_USB */
@@ -503,3 +554,4 @@ GOOD_OR_BAD ARG_Xport(const char *arg)
 	pin->type = ct_telnet ; // network
 	return gbGOOD;
 }
+
