@@ -1,9 +1,9 @@
 /*
-$Id: ow_com_close.c,v 1.7 2012/09/28 20:43:34 alfille Exp $
+$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
-	email: palfille@earthlink.net
+	email: paul.alfille@gmail.com
 	Released under the GPL
 	See the header file: ow.h for full attribution
 	1wire/iButton system from Dallas Semiconductor
