@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -18,8 +17,192 @@ $Id$
  * None the less, all settings are assigned to the head line
  */
  
- 
+/* lsusb for the TAI603B
+	Bus 001 Device 025: ID 10c4:ea60 Cygnal Integrated Products, Inc. CP210x UART Bridge / myAVR mySmartUSB light
+	Device Descriptor:
+	  bLength                18
+	  bDescriptorType         1
+	  bcdUSB               1.10
+	  bDeviceClass            0 (Defined at Interface level)
+	  bDeviceSubClass         0 
+	  bDeviceProtocol         0 
+	  bMaxPacketSize0        64
+	  idVendor           0x10c4 Cygnal Integrated Products, Inc.
+	  idProduct          0xea60 CP210x UART Bridge / myAVR mySmartUSB light
+	  bcdDevice            1.00
+	  iManufacturer           1 Silicon Labs
+	  iProduct                2 CP2102 USB to UART Bridge Controller
+	  iSerial                 3 0001
+	  bNumConfigurations      1
+	  Configuration Descriptor:
+		bLength                 9
+		bDescriptorType         2
+		wTotalLength           32
+		bNumInterfaces          1
+		bConfigurationValue     1
+		iConfiguration          0 
+		bmAttributes         0x80
+		  (Bus Powered)
+		MaxPower              100mA
+		Interface Descriptor:
+		  bLength                 9
+		  bDescriptorType         4
+		  bInterfaceNumber        0
+		  bAlternateSetting       0
+		  bNumEndpoints           2
+		  bInterfaceClass       255 Vendor Specific Class
+		  bInterfaceSubClass      0 
+		  bInterfaceProtocol      0 
+		  iInterface              2 CP2102 USB to UART Bridge Controller
+		  Endpoint Descriptor:
+			bLength                 7
+			bDescriptorType         5
+			bEndpointAddress     0x81  EP 1 IN
+			bmAttributes            2
+			  Transfer Type            Bulk
+			  Synch Type               None
+			  Usage Type               Data
+			wMaxPacketSize     0x0040  1x 64 bytes
+			bInterval               0
+		  Endpoint Descriptor:
+			bLength                 7
+			bDescriptorType         5
+			bEndpointAddress     0x01  EP 1 OUT
+			bmAttributes            2
+			  Transfer Type            Bulk
+			  Synch Type               None
+			  Usage Type               Data
+			wMaxPacketSize     0x0040  1x 64 bytes
+			bInterval               0
+*/
 
+/* lsusb for the USB9097 (PCsensor)
+	Bus 001 Device 037: ID 1a86:7523 QinHeng Electronics HL-340 USB-Serial adapter
+	Device Descriptor:
+	  bLength                18
+	  bDescriptorType         1
+	  bcdUSB               1.10
+	  bDeviceClass          255 Vendor Specific Class
+	  bDeviceSubClass         0 
+	  bDeviceProtocol         0 
+	  bMaxPacketSize0         8
+	  idVendor           0x1a86 QinHeng Electronics
+	  idProduct          0x7523 HL-340 USB-Serial adapter
+	  bcdDevice            2.54
+	  iManufacturer           0 
+	  iProduct                2 USB2.0-Serial
+	  iSerial                 0 
+	  bNumConfigurations      1
+	  Configuration Descriptor:
+		bLength                 9
+		bDescriptorType         2
+		wTotalLength           39
+		bNumInterfaces          1
+		bConfigurationValue     1
+		iConfiguration          0 
+		bmAttributes         0x80
+		  (Bus Powered)
+		MaxPower               96mA
+		Interface Descriptor:
+		  bLength                 9
+		  bDescriptorType         4
+		  bInterfaceNumber        0
+		  bAlternateSetting       0
+		  bNumEndpoints           3
+		  bInterfaceClass       255 Vendor Specific Class
+		  bInterfaceSubClass      1 
+		  bInterfaceProtocol      2 
+		  iInterface              0 
+		  Endpoint Descriptor:
+			bLength                 7
+			bDescriptorType         5
+			bEndpointAddress     0x82  EP 2 IN
+			bmAttributes            2
+			  Transfer Type            Bulk
+			  Synch Type               None
+			  Usage Type               Data
+			wMaxPacketSize     0x0020  1x 32 bytes
+			bInterval               0
+		  Endpoint Descriptor:
+			bLength                 7
+			bDescriptorType         5
+			bEndpointAddress     0x02  EP 2 OUT
+			bmAttributes            2
+			  Transfer Type            Bulk
+			  Synch Type               None
+			  Usage Type               Data
+			wMaxPacketSize     0x0020  1x 32 bytes
+			bInterval               0
+		  Endpoint Descriptor:
+			bLength                 7
+			bDescriptorType         5
+			bEndpointAddress     0x81  EP 1 IN
+			bmAttributes            3
+			  Transfer Type            Interrupt
+			  Synch Type               None
+			  Usage Type               Data
+			wMaxPacketSize     0x0008  1x 8 bytes
+			bInterval               1
+*/
+
+/* lsusb for the ECLO adapter
+	Bus 001 Device 035: ID 0403:ea90 Future Technology Devices International, Ltd Eclo 1-Wire Adapter
+	Device Descriptor:
+	  bLength                18
+	  bDescriptorType         1
+	  bcdUSB               2.00
+	  bDeviceClass            0 (Defined at Interface level)
+	  bDeviceSubClass         0 
+	  bDeviceProtocol         0 
+	  bMaxPacketSize0         8
+	  idVendor           0x0403 Future Technology Devices International, Ltd
+	  idProduct          0xea90 Eclo 1-Wire Adapter
+	  bcdDevice            4.00
+	  iManufacturer           1 Eclo
+	  iProduct                2 Eclo COM to 1-Wire USB adapter
+	  iSerial                 3 04000220
+	  bNumConfigurations      1
+	  Configuration Descriptor:
+		bLength                 9
+		bDescriptorType         2
+		wTotalLength           32
+		bNumInterfaces          1
+		bConfigurationValue     1
+		iConfiguration          0 
+		bmAttributes         0x80
+		  (Bus Powered)
+		MaxPower              500mA
+		Interface Descriptor:
+		  bLength                 9
+		  bDescriptorType         4
+		  bInterfaceNumber        0
+		  bAlternateSetting       0
+		  bNumEndpoints           2
+		  bInterfaceClass       255 Vendor Specific Class
+		  bInterfaceSubClass    255 Vendor Specific Subclass
+		  bInterfaceProtocol    255 Vendor Specific Protocol
+		  iInterface              2 Eclo COM to 1-Wire USB adapter
+		  Endpoint Descriptor:
+			bLength                 7
+			bDescriptorType         5
+			bEndpointAddress     0x81  EP 1 IN
+			bmAttributes            2
+			  Transfer Type            Bulk
+			  Synch Type               None
+			  Usage Type               Data
+			wMaxPacketSize     0x0040  1x 64 bytes
+			bInterval               0
+		  Endpoint Descriptor:
+			bLength                 7
+			bDescriptorType         5
+			bEndpointAddress     0x02  EP 2 OUT
+			bmAttributes            2
+			  Transfer Type            Bulk
+			  Synch Type               None
+			  Usage Type               Data
+			wMaxPacketSize     0x0040  1x 64 bytes
+			bInterval               0
+*/
 
 #include <config.h>
 #include "owfs_config.h"
@@ -77,6 +260,7 @@ static void DS2480_setroutines(struct connection_in *in)
 	in->iroutines.get_config = NO_GET_CONFIG_ROUTINE;
 	in->iroutines.reconnect = DS2480_reconnect ;
 	in->iroutines.close = DS2480_close;
+	in->iroutines.verify = NO_VERIFY_ROUTINE ;
 	in->iroutines.flags = ADAP_FLAG_default;
 	in->bundling_length = UART_FIFO_SIZE;
 }
@@ -629,12 +813,13 @@ static RESET_TYPE DS2480_reset_once(struct connection_in * in)
 	}
 }
 
+#define SERIAL_NUMBER_BITS (8*SERIAL_NUMBER_SIZE)
 /* search = normal and alarm */
 static enum search_status DS2480_next_both(struct device_search *ds, const struct parsedname *pn)
 {
 	int mismatched;
-	BYTE sn[8];
-	BYTE bitpairs[16];
+	BYTE sn[SERIAL_NUMBER_SIZE];
+	BYTE bitpairs[SERIAL_NUMBER_SIZE*2];
 	struct connection_in * in = pn->selected_connection ;
 	BYTE searchon = (BYTE) ( CMD_COMM | FUNCTSEL_SEARCHON | DS2480b_speed_byte(in) );
 	BYTE searchoff = (BYTE) ( CMD_COMM | FUNCTSEL_SEARCHOFF | DS2480b_speed_byte(in) );
@@ -654,6 +839,9 @@ static enum search_status DS2480_next_both(struct device_search *ds, const struc
 		return search_done;
 	}
 
+	// clear sn to satisfy static error checking (Coverity)
+	memset( sn, 0, SERIAL_NUMBER_SIZE ) ;
+	
 	// build the command stream
 	// call a function that may add the change mode command to the buff
 	// check if correct mode
@@ -666,7 +854,7 @@ static enum search_status DS2480_next_both(struct device_search *ds, const struc
 	mismatched = -1;
 
 	// add the 16 bytes of the search
-	memset(bitpairs, 0, 16);
+	memset(bitpairs, 0, SERIAL_NUMBER_SIZE*2);
 
 	// set the bits in the added buffer
 	for (i = 0; i < ds->LastDiscrepancy; i++) {
@@ -689,14 +877,14 @@ static enum search_status DS2480_next_both(struct device_search *ds, const struc
 	// search OFF
 	if ( BAD(BUS_send_data(&(ds->search), 1, pn))
 		|| BAD(DS2480_sendout_cmd(&searchon, 1, in))
-		|| BAD( DS2480_sendback_data(bitpairs, bitpairs, 16, pn) )
+		|| BAD( DS2480_sendback_data(bitpairs, bitpairs, SERIAL_NUMBER_SIZE*2, pn) )
 		|| BAD(DS2480_sendout_cmd(&searchoff, 1, in))
 		) {
 		return search_error;
 	}
 
 	// interpret the bit stream
-	for (i = 0; i < 64; i++) {
+	for (i = 0; i < SERIAL_NUMBER_BITS; i++) {
 		// get the SerialNum bit
 		UT_setbit(sn, i, UT_get2bit(bitpairs, i) >> 1);
 		// check LastDiscrepancy
@@ -711,7 +899,7 @@ static enum search_status DS2480_next_both(struct device_search *ds, const struc
 	}
 
 	// CRC check
-	if (CRC8(sn, 8) || (ds->LastDiscrepancy == 63) || (sn[0] == 0)) {
+	if (CRC8(sn, SERIAL_NUMBER_SIZE) || (ds->LastDiscrepancy == SERIAL_NUMBER_BITS-1) || (sn[0] == 0)) {
 		return search_error;
 	}
 
