@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
 
@@ -67,6 +66,7 @@ static void PBM_setroutines(struct connection_in *in)
 	in->iroutines.get_config = NO_GET_CONFIG_ROUTINE;
 	in->iroutines.reconnect = PBM_reconnect;
 	in->iroutines.close = PBM_close;
+	in->iroutines.verify = NO_VERIFY_ROUTINE ;
 	in->iroutines.flags = ADAP_FLAG_no2409path | ADAP_FLAG_no2404delay | ADAP_FLAG_unlock_during_delay;
 	in->bundling_length = PBM_FIFO_SIZE;
 }
@@ -336,7 +336,10 @@ static RESET_TYPE PBM_reset_in(struct connection_in * in)
 		PBM_flush(in);
 	}
 
-	PBM_SelectChannel(in);
+	if ( BAD(PBM_SelectChannel(in)) ) {
+		return BUS_RESET_ERROR ;
+	};
+	
 	if ( BAD(PBM_write(PBM_string("r"), 1, in) || BAD( PBM_read(resp, 1, in))) ) {
 		LEVEL_DEBUG("Error resetting PBM device");
 		PBM_slurp(in);
@@ -385,7 +388,7 @@ static enum search_status PBM_next_both(struct device_search *ds, const struct p
 
 	switch ( DirblobGet(ds->index, ds->sn, &(ds->gulp) ) ) {
 		case 0:
-			LEVEL_DEBUG("SN found: " SNformat "", SNvar(ds->sn));
+			LEVEL_DEBUG("SN found: " SNformat, SNvar(ds->sn));
 			return search_good;
 		case -ENODEV:
 		default:
