@@ -1,9 +1,9 @@
 /*
-$Id: ow_eprom_write.c,v 1.10 2010/05/03 17:46:44 alfille Exp $
+$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
-	email: palfille@earthlink.net
+	email: paul.alfille@gmail.com
 	Released under the GPL
 	See the header file: ow.h for full attribution
 	1wire/iButton system from Dallas Semiconductor
