@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -19,6 +18,13 @@ $Id$
 
 static void External_setroutines(struct connection_in *in);
 
+/* External program link
+ * Use programs instead of 1-wire slave
+ * The initial setup is in ow_parse_external.c
+ * Reads and writes are in ow_read_external.c and ow_write_external.c
+ * and ___ in ow_fi9nd_external.c
+ * */
+
 static void External_setroutines(struct connection_in *in)
 {
 	in->iroutines.detect = External_detect;
@@ -34,6 +40,7 @@ static void External_setroutines(struct connection_in *in)
 	in->iroutines.get_config = NO_GET_CONFIG_ROUTINE;
 	in->iroutines.reconnect = NO_RECONNECT_ROUTINE;
 	in->iroutines.close = NO_CLOSE_ROUTINE;
+	in->iroutines.verify = NO_VERIFY_ROUTINE ;
 	in->iroutines.flags = 0 ;
 	in->bundling_length = 1;
 }
