@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -24,12 +23,12 @@ ZERO_OR_ERROR FS_r_alias(struct one_wire_query *owq)
 
 	if ( alias_name != NULL ) {
 		ZERO_OR_ERROR zoe = OWQ_format_output_offset_and_size_z(alias_name, owq);
-		LEVEL_DEBUG("Found alias %s for "SNformat"\n",alias_name,SNvar(sn));
+		LEVEL_DEBUG("Found alias %s for "SNformat,alias_name,SNvar(sn));
 		owfree( alias_name ) ;
 		return zoe;
 	}
 
-	LEVEL_DEBUG("Didn't find alias %s for "SNformat"\n",alias_name,SNvar(sn));
+	LEVEL_DEBUG("Didn't find alias %s for "SNformat,alias_name,SNvar(sn));
 	return OWQ_format_output_offset_and_size_z("", owq);
 }
 
