@@ -1,9 +1,9 @@
 /*
-$Id: ow_generic_read.c,v 1.4 2010/09/24 21:04:24 alfille Exp $
+$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
-	email: palfille@earthlink.net
+	email: paul.alfille@gmail.com
 	Released under the GPL
 	See the header file: ow.h for full attribution
 	1wire/iButton system from Dallas Semiconductor
@@ -14,6 +14,7 @@ $Id: ow_generic_read.c,v 1.4 2010/09/24 21:04:24 alfille Exp $
 #include "ow_generic_read.h"
 
 /* ------- Prototypes ----------- */
+/*
 static ZERO_OR_ERROR UnpagedRead( struct generic_read * gread, struct one_wire_query *owq )
 {
 	size_t size = OWQ_size(owq) ;
@@ -40,6 +41,7 @@ static ZERO_OR_ERROR UnpagedRead( struct generic_read * gread, struct one_wire_q
 	owfree(p) ;
 	return 0 ;
 }
+*/
 
 ZERO_OR_ERROR Generic_Read( struct one_wire_query *owq)
 {
