@@ -8,6 +8,8 @@
 	1wire/iButton system from Dallas Semiconductor
 */
 
+// regex
+
 #include <config.h>
 #include "owfs_config.h"
 #include "ow.h"
@@ -137,7 +139,7 @@ static enum search_status HA7E_next_both(struct device_search *ds, const struct
 
 	switch ( DirblobGet(ds->index, ds->sn, &(ds->gulp)) ) {
 	case 0:
-		LEVEL_DEBUG("SN found: " SNformat "\n", SNvar(ds->sn));
+		LEVEL_DEBUG("SN found: " SNformat, SNvar(ds->sn));
 		return search_good;
 	case -ENODEV:
 	default:
