@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -26,6 +25,9 @@ void LibStop(void)
 	FreeInAll();
 	LEVEL_CALL("Closing output devices");
 	FreeOutAll();
+	LEVEL_CALL("Clearing compiled expressions");
+	ow_regdestroy() ;
+
 
 	/* Have to reset more internal variables, and this should be fixed
 	 * by setting optind = 0 and call getopt()
