@@ -10,14 +10,6 @@
 
 /* ow_opt -- owlib specific command line options processing */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#include <stdio.h> // for getline
-#undef _GNU_SOURCE
-#else
-#include <stdio.h> // for getline
-#endif
-
 #include <config.h>
 #include "owfs_config.h"
 #include "ow.h"
@@ -50,6 +42,8 @@ const struct option owopts_long[] = {
 	{"aliases", required_argument, NO_LINKED_VAR, 'a'},
 	{"aliasfile", required_argument, NO_LINKED_VAR, 'a'},
 	{"configuration", required_argument, NO_LINKED_VAR, 'c'},
+	{"config", required_argument, NO_LINKED_VAR, 'c'},
+	{"conf", required_argument, NO_LINKED_VAR, 'c'},
 	{"device", required_argument, NO_LINKED_VAR, 'd'},
 	{"usb", optional_argument, NO_LINKED_VAR, 'u'},
 	{"USB", optional_argument, NO_LINKED_VAR, 'u'},
@@ -117,10 +111,6 @@ const struct option owopts_long[] = {
 	{"error-level", required_argument, NO_LINKED_VAR, e_error_level},
 	{"errorlevel", required_argument, NO_LINKED_VAR, e_error_level},
 	{"debug", no_argument, NO_LINKED_VAR, e_debug},
-	{"concurrent_connections", required_argument, NO_LINKED_VAR, e_concurrent_connections},
-	{"concurrent-connections", required_argument, NO_LINKED_VAR, e_concurrent_connections},
-	{"max-connections", required_argument, NO_LINKED_VAR, e_concurrent_connections},
-	{"max_connections", required_argument, NO_LINKED_VAR, e_concurrent_connections},
 	{"cache_size", required_argument, NO_LINKED_VAR, e_cache_size},	/* max cache size */
 	{"cache-size", required_argument, NO_LINKED_VAR, e_cache_size},	/* max cache size */
 	{"cachesize", required_argument, NO_LINKED_VAR, e_cache_size},	/* max cache size */
@@ -136,6 +126,10 @@ const struct option owopts_long[] = {
 
 	{"passive", required_argument, NO_LINKED_VAR, e_passive},	/* DS9097 passive */
 	{"PASSIVE", required_argument, NO_LINKED_VAR, e_passive},	/* DS9097 passive */
+	{"ds1wm", required_argument, NO_LINKED_VAR, e_ds1wm},	/* DS1WM synthesizable adapters */
+	{"DS1WM", required_argument, NO_LINKED_VAR, e_ds1wm},	/* DS1WM synthesizable adapters */
+	{"k1wm", required_argument, NO_LINKED_VAR, e_k1wm},	/* DS1WM synthesizable adapters */
+	{"K1WM", required_argument, NO_LINKED_VAR, e_k1wm},	/* DS1WM synthesizable adapters */
 	{"i2c", optional_argument, NO_LINKED_VAR, e_i2c},	/* i2c adapters */
 	{"I2C", optional_argument, NO_LINKED_VAR, e_i2c},	/* i2c adapters */
 	{"HA7", optional_argument, NO_LINKED_VAR, e_ha7},	/* HA7Net */
@@ -203,8 +197,6 @@ const struct option owopts_long[] = {
 	{"USB_flextime", no_argument, &Globals.usb_flextime, 1},
 	{"usb_regulartime", no_argument, &Globals.usb_flextime, 0},
 	{"USB_regulartime", no_argument, &Globals.usb_flextime, 0},
-	{"usb_scan", optional_argument, NO_LINKED_VAR, e_usb_monitor,},
-	{"USB_scan", optional_argument, NO_LINKED_VAR, e_usb_monitor,},
 	{"serial_flex", no_argument, &Globals.serial_flextime, 1},
 	{"serial_flextime", no_argument, &Globals.serial_flextime, 1},
 	{"serial_regulartime", no_argument, &Globals.serial_flextime, 0},
@@ -287,6 +279,12 @@ const struct option owopts_long[] = {
 	{"TRIM", no_argument, &Globals.trim, 1},
 	{"detail", required_argument, NO_LINKED_VAR, e_detail},	/* slave detail */
 	{"details", required_argument, NO_LINKED_VAR, e_detail},	/* slave detail */
+	{"traffic", no_argument, &Globals.traffic, 1},
+	{"notraffic", no_argument, &Globals.traffic, 0},
+	{"no_traffic", no_argument, &Globals.traffic, 0},
+	{"locks", no_argument, &Globals.locks, 1},
+	{"nolocks", no_argument, &Globals.locks, 0},
+	{"no_locks", no_argument, &Globals.locks, 0},
 	{0, 0, 0, 0},
 };
 
@@ -439,7 +437,7 @@ static void ParseTheLine(struct lineparse *lp)
 						{	// put in lower case
 							ASCII *prog_char;
 							for (prog_char = lp->prog; *prog_char; ++prog_char) {
-								*prog_char = tolower(*prog_char);
+								*prog_char = tolower( (int) prog_char[0] );
 							}
 						}
 						// special cases for sensor and property lines
@@ -579,6 +577,8 @@ GOOD_OR_BAD owopt_packed(const char *params)
 	}
 
 	// analyze argv/argc as if real command line arguments
+	ArgCopy( argc, argv ) ;
+
 	while (ret == 0) {
 		if ((option_char = getopt_long(argc, argv, OWLIB_OPT, owopts_long, NULL)) == -1) {
 			break;
@@ -621,6 +621,7 @@ GOOD_OR_BAD owopt(const int option_char, const char *arg)
 		} else {
 			GOOD_OR_BAD ret;
 			++config_depth;
+			Config_Monitor_Add( arg ) ; // add for monitoring changes
 			ret = ConfigurationFile(arg);
 			--config_depth;
 			return ret;
@@ -731,7 +732,11 @@ GOOD_OR_BAD owopt(const int option_char, const char *arg)
 		break;
 	case e_debug:
 		// shortcut for --foreground --error_level=9
+#if OW_DEBUG
 		printf("DEBUG MODE\n");
+#else
+		printf("DEBUG MODE disabled at compile time. Sorry.\n");
+#endif /* OW_DEBUG */
 		printf("libow version:\n\t" VERSION "\n");
 		switch (Globals.daemon_status) {
 			case e_daemon_want_bg:
@@ -743,10 +748,6 @@ GOOD_OR_BAD owopt(const int option_char, const char *arg)
 		Globals.error_level = 9 ;
 		Globals.error_level_restore = 9 ;
 		break ;
-	case e_concurrent_connections:
-		RETURN_BAD_IF_BAD(OW_parsevalue_I(&arg_to_integer, arg)) ;
-		Globals.concurrent_connections = (int) arg_to_integer;
-		break;
 	case e_cache_size:
 		RETURN_BAD_IF_BAD(OW_parsevalue_I(&arg_to_integer, arg)) ;
 		Globals.cache_size = (size_t) arg_to_integer;
@@ -819,8 +820,10 @@ GOOD_OR_BAD owopt(const int option_char, const char *arg)
 		return ARG_MasterHub(arg);
 	case e_w1_monitor:
 		return ARG_W1_monitor();
-	case e_usb_monitor:
-		return ARG_USB_monitor(arg);
+	case e_ds1wm:
+		return ARG_DS1WM(arg);
+	case e_k1wm:
+		return ARG_K1WM(arg);
 	case e_browse:
 		return ARG_Browse();
 	case e_announce:
