@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -16,6 +15,8 @@ $Id$
  * quote and double quote matching
  * */
 
+/* 11/2014 -- considerable testing and patches from Sven Giermann */
+
 #include <config.h>
 #include "owfs_config.h"
 #include "ow.h"
@@ -41,7 +42,7 @@ void * property_tree = NULL ;
 void * family_tree = NULL ;
 void * sensor_tree = NULL ;
 
-// ForAddSensor and AddProperty
+// For AddSensor and AddProperty
 // uses the various tools to get a string into s_name (name is given)
 // start_pointer (a char *) is used and updated.
 #define GetQuotedString( name ) do {                               \
@@ -52,6 +53,7 @@ void * sensor_tree = NULL ;
 		++ start_pointer ;                                        \
 	}                                                             \
 	s_##name = unquote_parse( trim_parse( s_##name ) ) ;          \
+	LEVEL_DEBUG( #name" assigned %s",s_##name ) ;               \
 } while (0) ;
 
 // Look through text_string, ignore backslash and match quoting varibles
@@ -134,22 +136,47 @@ static char * trim_parse( char * raw_string )
 	char * start_position ;
 	char * end_position ;
 	char * return_string ;
+
+	// trim off preamble whitespace
 	for ( start_position = raw_string ; start_position[0] ; ++ start_position ) {
-		if ( start_position[0] != ' ' ) {
-			break ;
+		switch ( start_position[0] ) {
+			case ' ':
+			case '\t':
+			// ignore these characters
+				continue ;
+			case '\n':
+			case '\r':
+				// end of the line -- empty string return
+				owfree( raw_string );
+				return owstrdup("") ;
+			default:
+				break ;
 		}
+		// getting here means a valid character found
+		break ;
 	}
+
+	// delete old string and use new copy starting at first non whitespace position
 	return_string = owstrdup ( start_position ) ;
 	owfree( raw_string ) ;
 	
+	// trim off 
 	for ( end_position = return_string + strlen( return_string ) ; end_position >= return_string ; -- end_position ) {
-		if ( end_position[0] == '\0' ) {
-			continue ;
-		} else if ( end_position[0] != ' ' ) {
-			break ;
-		} else {
-			end_position[0] = '\0' ;
+		switch ( end_position[0] ) {
+			case ' ':
+			case '\0':
+			case '\r':
+			case '\n':
+			case '\t':
+				// ignorable end char -- make null
+				end_position[0] = '\0' ;
+				continue ;
+			default:
+				// good char
+				break ;			
 		}
+		// getting here means a valid character found
+		break ;
 	}
 	
 	return return_string ;
@@ -161,23 +188,23 @@ static char * unquote_parse( char * raw_string )
 		return NULL ;
 	}
 	switch ( raw_string[0] ) {		
-	case '"':
-	case '\'':
-		if ( raw_string[1] == '\0' ) {
-			owfree( raw_string ) ;
-			return owstrdup("") ;
-		} else {
-			char * unquoted = owstrdup( raw_string+1 ) ;
-			char * unquoted_end = unquoted + strlen(unquoted) -1 ;
-			if ( unquoted_end[0] == raw_string[0] ) {
-				unquoted_end[0] = '\0' ;
+		case '"':
+		case '\'':
+			if ( raw_string[1] == '\0' ) {
+				owfree( raw_string ) ;
+				return owstrdup("") ;
+			} else {
+				char * unquoted = owstrdup( raw_string+1 ) ;
+				char * unquoted_end = unquoted + strlen(unquoted) -1 ;
+				if ( unquoted_end[0] == raw_string[0] ) {
+					unquoted_end[0] = '\0' ;
+				}
+				owfree( raw_string ) ;
+				return unquoted ;
 			}
-			owfree( raw_string ) ;
-			return unquoted ;
-		}
-		break ;
-	default:
-		return raw_string ;
+			break ;
+		default:
+			return raw_string ;
 	}
 }	
 	
@@ -200,6 +227,9 @@ static int LastParam( char * input_string )
 
 // Gets a string with property,family,structure,read_function,write_function,property_data,extra
 // write, data and extra are optional
+
+// starts with script:
+// or property:
 /*
  * property
  * family
@@ -231,7 +261,7 @@ void AddProperty( char * input_string, enum external_type et )
 	}
 	
 	if ( ! Globals.allow_external ) {
-		LEVEL_DEBUG("External prgroams not supported by %s",Globals.progname) ;
+		LEVEL_DEBUG("External prgroams not supported by %s",Globals.argv[0]) ;
 		return ;
 	}
 
@@ -327,8 +357,8 @@ void AddProperty( char * input_string, enum external_type et )
 			}
 			break ;
 		case '+':
-			if ( isalpha(s_dummy[1]) ) {
-				s_array = toupper(s_dummy[1]) - 'A' ;
+			if ( isalpha( (int) s_dummy[1] ) ) {
+				s_array = toupper( (int) s_dummy[1] ) - 'A' ;
 				s_combined = ag_aggregate ;
 				s_index_type = ag_letters ;
 			} else {
@@ -338,8 +368,8 @@ void AddProperty( char * input_string, enum external_type et )
 			}
 			break ;
 		default:
-			if ( isalpha(s_dummy[0]) ) {
-				s_array = toupper(s_dummy[0]) - 'A' ;
+			if ( isalpha( (int) s_dummy[0] ) ) {
+				s_array = toupper( (int) s_dummy[0] ) - 'A' ;
 				s_combined = ag_separate ;
 				s_index_type = ag_letters ;
 			} else {
@@ -426,7 +456,7 @@ void AddSensor( char * input_string )
 	}
 	
 	if ( ! Globals.allow_external ) {
-		LEVEL_DEBUG("External prgroams not supported by %s",Globals.progname) ;
+		LEVEL_DEBUG("External prgroams not supported by %s",Globals.argv[0]) ;
 		return ;
 	}
 	
@@ -520,22 +550,22 @@ static struct family_node * create_family_node( char * s_family )
 
 static struct property_node * create_property_node( char * s_property, char * s_family, enum ft_format s_format, size_t s_array, enum ag_combined s_combined, enum ag_index s_index_type, size_t s_length, enum fc_change s_change, char * s_read, char * s_write, char * s_data, char * s_other, enum external_type et )
 {
+	// AddPropertyToTree (the calling routine) ensures these aren't null
 	int l_property = strlen( s_property )+1 ;
 	int l_family = strlen( s_family )+1 ;
 	int l_read = strlen( s_read )+1 ;
 	int l_write = strlen( s_write )+1 ;
 	int l_data = strlen( s_data )+1 ;
 	int l_other = strlen( s_other )+1 ;
-
-	struct property_node * s = owmalloc( sizeof(struct property_node) 
-	+ l_property + l_family + l_read + l_write + l_data + l_other ) ;
+	int l_total = sizeof(struct property_node) + l_property + l_family + l_read + l_write + l_data + l_other ;
+	
+	struct property_node * s = owmalloc( l_total ) ;
 	
 	if ( s==NULL) {
 		return NULL ;
 	}
 
-	memset( s, 0, sizeof(struct property_node) 
-	+ l_property + l_family + l_read + l_write + l_data + l_other ) ;
+	memset( s, 0, l_total ) ;
 
 	s->property = s->payload ;
 	strcpy( s->property, s_property ) ;
@@ -569,12 +599,12 @@ static struct property_node * create_property_node( char * s_property, char * s_
 	s->ft.data.a = s->data ;
 	
 	// Check read function
-	if ( s_read != NULL && strlen(s_read) > 0 ) {
+	if ( l_read > 1 ) {
 		s->ft.read = FS_r_external ;
 	}
 	
 	// Check write function
-	if ( s_write != NULL && strlen(s_write) > 0 ) {
+	if ( l_write > 1 ) {
 		s->ft.write = FS_w_external ;
 	}
 	
@@ -626,13 +656,25 @@ static void AddFamilyToTree( char * s_family )
 	}
 }
 
+#define NonNull(x)  if(x==NULL) { x=""; }
+
 static void AddPropertyToTree( char * s_property, char * s_family, enum ft_format s_format, size_t s_array, enum ag_combined s_combined, enum ag_index s_index_type, size_t s_length, enum fc_change s_change, char * s_read, char * s_write, char * s_data, char * s_other, enum external_type et )
 {
-	struct property_node * n = create_property_node( s_property, s_family, s_format, s_array, s_combined, s_index_type, s_length, s_change, s_read, s_write, s_data, s_other, et ) ;
+	struct property_node * n  ;
 	struct {
 		struct property_node * key ;
 		char other[0] ;
-	} * opaque = tsearch( (void *) n, &property_tree, property_compare ) ;
+	} * opaque ;
+	
+	NonNull( s_property )
+	NonNull( s_family )
+	NonNull( s_read )
+	NonNull( s_write )
+	NonNull( s_data )
+	NonNull( s_other )
+
+	n = create_property_node( s_property, s_family, s_format, s_array, s_combined, s_index_type, s_length, s_change, s_read, s_write, s_data, s_other, et ) ;
+	opaque = tsearch( (void *) n, &property_tree, property_compare ) ;
 	
 	if ( opaque->key != n ) {
 		// already exists
