@@ -1,9 +1,9 @@
 /*
-$Id: ow_printparse.c,v 1.7 2011/07/27 19:30:09 alfille Exp $
+$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
-    email: palfille@earthlink.net
+    email: paul.alfille@gmail.com
     Released under the GPL
     See the header file: ow.h for full attribution
     1wire/iButton system from Dallas Semiconductor
@@ -18,7 +18,7 @@ $Id: ow_printparse.c,v 1.7 2011/07/27 19:30:09 alfille Exp $
 void _print_owq(struct one_wire_query *owq)
 {
 	char c[32];
-	fprintf(stderr,"OWQ OneWireQuery structure of %s\n", OWQ_pn(owq).path);
+	fprintf(stderr,"OWQ OneWireQuery structure of %s\n", PN(owq)->path);
 	fprintf(stderr,"    OneWireQuery size=%lu offset=%lu, extension=%d\n",
 		   (unsigned long) OWQ_size(owq), (unsigned long) OWQ_offset(owq), (int) OWQ_pn(owq).extension);
 	if ( OWQ_buffer(owq) != NULL ) {
