@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -7,7 +6,6 @@ $Id$
     Released under the GPL
     See the header file: ow.h for full attribution
     1wire/iButton system from Dallas Semiconductor
-$ID: $
 */
 
 #include <config.h>
@@ -70,11 +68,6 @@ SIZE_OR_ERROR FS_read_postparse(struct one_wire_query *owq)
 	struct parsedname *pn = PN(owq);
 	SIZE_OR_ERROR read_or_error;
 
-	// ServerRead jumps in here, perhaps with non-file entry
-	if (pn->selected_device == NO_DEVICE || pn->selected_filetype == NO_FILETYPE) {
-		return -EISDIR;
-	}
-
 	/* Normal read. Try three times */
 	LEVEL_DEBUG("%s", pn->path);
 	STATLOCK;
@@ -85,7 +78,19 @@ SIZE_OR_ERROR FS_read_postparse(struct one_wire_query *owq)
 	/* First try */
 	STAT_ADD1(read_tries[0]);
 
-	read_or_error = (pn->type == ePN_real) ? FS_read_real(owq) : FS_r_virtual(owq);
+	/* Check file type. */
+	if (pn->selected_device == NO_DEVICE || pn->selected_filetype == NO_FILETYPE) {
+		if (KnownBus(pn) && BusIsServer(pn->selected_connection)) {
+			/* Pass unknown remote filetype to remote owserver. */
+			read_or_error = FS_r_given_bus(owq);
+		} else {
+			/* Local unknown filetypes are directories. */
+			return -EISDIR;
+		}	
+	} else {
+		/* Local known filetypes are handled here. */
+		read_or_error = (pn->type == ePN_real) ? FS_read_real(owq) : FS_r_virtual(owq);
+	}
 
 	STATLOCK;
 	if (read_or_error >= 0) {
@@ -367,8 +372,10 @@ static SIZE_OR_ERROR FS_r_local(struct one_wire_query *owq)
 			case adapter_mock:
 				/* Special case for "mock" adapter */
 				if ( GOOD( OWQ_Cache_Get(owq)) ) {	// cached
+					LEVEL_DEBUG("Mock value in cache");
 					return 0;
 				}
+				LEVEL_DEBUG("Mock value NOT in cache");
 				return FS_read_fake(owq);
 			default:
 				break ;
@@ -781,7 +788,7 @@ static ZERO_OR_ERROR FS_read_a_part( struct one_wire_query *owq_part )
 			char *buffer_pointer = OWQ_buffer(owq_all);
 
 			// All prior elements
-			for (extension_index = 0; extension_index < extension; ++extension) {
+			for (extension_index = 0; extension_index < extension; ++extension_index) {
 				// move past their buffer position
 				buffer_pointer += OWQ_array_length(owq_all, extension_index);
 			}
