@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -8,6 +7,7 @@ $Id$
 	See the header file: ow.h for full attribution
 	1wire/iButton system from Dallas Semiconductor
 */
+// regex
 
 #include <config.h>
 #include "owfs_config.h"
@@ -125,9 +125,9 @@ GOOD_OR_BAD telnet_read(BYTE * buf, const size_t size, struct connection_in *in)
 		switch ( telnet_read_state ) {
 			case telnet_regular :
 				if ( readin_buf[current_index] == TELNET_IAC ) {
-#if OW_SHOW_TRAFFIC
-					LEVEL_DEBUG("TELNET: IAC");
-#endif /* OW_SHOW_TRAFFIC */
+						if (Globals.traffic) {
+							LEVEL_DEBUG("TELNET: IAC");
+						}
 					// starting escape sequence
 					// following bytes will better characterize
 					telnet_read_state = telnet_iac ;
@@ -158,9 +158,9 @@ GOOD_OR_BAD telnet_read(BYTE * buf, const size_t size, struct connection_in *in)
 					case TELNET_GA:
 						// 2 byte sequence
 						// just read 2nd character
-#if OW_SHOW_TRAFFIC
-						LEVEL_DEBUG("TELNET: End 2-byte sequence");
-#endif /* OW_SHOW_TRAFFIC */
+						if (Globals.traffic) {
+							LEVEL_DEBUG("TELNET: End 2-byte sequence");
+						}
 						telnet_read_state = telnet_regular ;
 						break ;
 					case TELNET_SB:
@@ -193,9 +193,9 @@ GOOD_OR_BAD telnet_read(BYTE * buf, const size_t size, struct connection_in *in)
 						// make this a single regular FF char
 						buf[size - still_needed] = 0xFF ;
 						-- still_needed ;
-#if OW_SHOW_TRAFFIC
-						LEVEL_DEBUG("TELNET: FF escape sequence");
-#endif /* OW_SHOW_TRAFFIC */
+						if (Globals.traffic) {
+							LEVEL_DEBUG("TELNET: FF escape sequence");
+						}
 						telnet_read_state = telnet_regular ;
 						break ;
 					default:
@@ -243,9 +243,9 @@ GOOD_OR_BAD telnet_read(BYTE * buf, const size_t size, struct connection_in *in)
 				switch ( readin_buf[current_index] ) {
 					case TELNET_SE:
 						//printf("TELNET: IAC SE\n");
-#if OW_SHOW_TRAFFIC
-						LEVEL_DEBUG("TELNET: End multi-byte sequence");
-#endif /* OW_SHOW_TRAFFIC */
+						if (Globals.traffic) {
+							LEVEL_DEBUG("TELNET: End multi-byte sequence");
+						}
 						telnet_read_state = telnet_regular ;
 						break ;					
 					default:
@@ -257,35 +257,35 @@ GOOD_OR_BAD telnet_read(BYTE * buf, const size_t size, struct connection_in *in)
 				//printf("TELNET: IAC WILL %d\n",readin_buf[current_index]);
 				// 3 byte sequence
 				// now reading 3rd char
-#if OW_SHOW_TRAFFIC
-				LEVEL_DEBUG("TELNET: End 3-byte sequence");
-#endif /* OW_SHOW_TRAFFIC */
+				if (Globals.traffic) {
+					LEVEL_DEBUG("TELNET: End 3-byte sequence");
+				}
 				telnet_read_state = telnet_regular ;
 				break ;
 			case telnet_wont:
 				//printf("TELNET: IAC WONT %d\n",readin_buf[current_index]);
 				// 3 byte sequence
 				// now reading 3rd char
-#if OW_SHOW_TRAFFIC
-				LEVEL_DEBUG("TELNET: End 3-byte sequence");
-#endif /* OW_SHOW_TRAFFIC */
+				if (Globals.traffic) {
+					LEVEL_DEBUG("TELNET: End 3-byte sequence");
+				}
 				telnet_read_state = telnet_regular ;
 				break ;
 			case telnet_do:
 				//printf("TELNET: IAC DO %d\n",readin_buf[current_index]);
 				// 3 byte sequence
 				// now reading 3rd char
-#if OW_SHOW_TRAFFIC
-				LEVEL_DEBUG("TELNET: End 3-byte sequence");
-#endif /* OW_SHOW_TRAFFIC */
+				if (Globals.traffic) {
+					LEVEL_DEBUG("TELNET: End 3-byte sequence");
+				}
 				telnet_read_state = telnet_regular ;
 				break ;
 			case telnet_dont:
 				// 3 byte sequence
 				// now reading 3rd char
-#if OW_SHOW_TRAFFIC
-				LEVEL_DEBUG("TELNET: End 3-byte sequence");
-#endif /* OW_SHOW_TRAFFIC */
+				if (Globals.traffic) {
+					LEVEL_DEBUG("TELNET: End 3-byte sequence");
+				}
 				telnet_read_state = telnet_regular ;
 				break ;
 		}
