@@ -1,9 +1,9 @@
 /*
-$Id: ow_search.c,v 1.30 2011/07/20 02:13:16 alfille Exp $
+$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
-    email: palfille@earthlink.net
+    email: paul.alfille@gmail.com
     Released under the GPL
     See the header file: ow.h for full attribution
     1wire/iButton system from Dallas Semiconductor
@@ -91,7 +91,7 @@ void BUS_next_cleanup( struct device_search *ds )
 
 
 /* try the directory search 3 times.
- * Since ds->LastDescrepancy is alertered only on success a repeat is legal
+ * Since ds->LastDescrepancy is altered only on success a repeat is legal
  * */
 static enum search_status BUS_next_3try(struct device_search *ds, const struct parsedname *pn)
 {
