@@ -287,7 +287,7 @@ static enum search_status OWServer_Enet_next_both(struct device_search *ds, cons
 
 	switch ( DirblobGet(ds->index, ds->sn, &(ds->gulp) ) ) {
 		case 0:
-			LEVEL_DEBUG("SN found: " SNformat "", SNvar(ds->sn));
+			LEVEL_DEBUG("SN found: " SNformat, SNvar(ds->sn));
 			return search_good;
 		case -ENODEV:
 		default:
