@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -51,7 +50,7 @@ void COM_slurp( struct connection_in * connection ) {
 			LEVEL_DEBUG("Unimplemented");
 			return ;
 		case ct_serial:
-			usec = 1000 ;
+			usec = 100000 ; // timeout increased for slurp based on Johan Strom's recommendation
 			break ;
 	}
 
