@@ -1,9 +1,9 @@
 /*
-$Id: ow_tcp_free.c,v 1.2 2012/01/23 02:33:47 alfille Exp $
+$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
-	email: palfille@earthlink.net
+	email: paul.alfille@gmail.com
 	Released under the GPL
 	See the header file: ow.h for full attribution
 	1wire/iButton system from Dallas Semiconductor
@@ -26,10 +26,6 @@ $Id: ow_tcp_free.c,v 1.2 2012/01/23 02:33:47 alfille Exp $
 /* Called on head of multigroup bus */
 void tcp_free(struct connection_in *connection)
 {
-	if ( SOC(connection)->state == cs_virgin ) {
-		return ;
-	}
-
 	COM_close( connection ) ;
 	FreeClientAddr( connection ) ;
 }
