@@ -1,9 +1,9 @@
 /*
-$Id: ow_tree.c,v 1.67 2011/12/20 03:41:13 alfille Exp $
+$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
-    email: palfille@earthlink.net
+    email: paul.alfille@gmail.com
     Released under the GPL
     See the header file: ow.h for full attribution
     1wire/iButton system from Dallas Semiconductor
@@ -13,10 +13,12 @@ $Id: ow_tree.c,v 1.67 2011/12/20 03:41:13 alfille Exp $
 #include "owfs_config.h"
 #include "ow.h"
 #include "ow_devices.h"
+#include "ow_external.h"
 
 static int device_compare(const void *a, const void *b);
 static int file_compare(const void *a, const void *b);
 static void Device2Tree(const struct device *d, enum ePN_type type);
+static void External_Process(void);
 
 struct device *DeviceSimultaneous;
 struct device *DeviceThermostat;
@@ -78,6 +80,13 @@ static void free_node(void *nodep)
 void DeviceDestroy(void)
 {
 	UINT i;
+
+	// clear external trees
+	tdestroy( sensor_tree, owfree_func ) ;
+	tdestroy( family_tree, owfree_func ) ;
+	tdestroy( property_tree, owfree_func ) ;
+
+	// clear these trees -- have static data
 	for (i = 0; i < (sizeof(Tree) / sizeof(void *)); i++) {
 		/* ePN_structure is just a duplicate of ePN_real */
 		if (i != ePN_structure) {
@@ -155,6 +164,11 @@ void DeviceSort(void)
 	Device2Tree( & d_HobbyBoards_EE, ePN_real);
 	Device2Tree( & d_HobbyBoards_EF, ePN_real);
 	Device2Tree( & d_LCD,            ePN_real);
+	Device2Tree( & d_mAM001,         ePN_real);
+	Device2Tree( & d_mCM001,         ePN_real);
+	Device2Tree( & d_mRS001,         ePN_real);
+	Device2Tree( & d_mTS017,         ePN_real);
+	Device2Tree( & d_mDI001,         ePN_real);
 	Device2Tree( & d_simultaneous,   ePN_real);
 	
 	Device2Tree( & d_stats_cache,          ePN_statistics);
@@ -176,6 +190,9 @@ void DeviceSort(void)
 
 	Device2Tree( & d_interface_settings,   ePN_interface);
 	Device2Tree( & d_interface_statistics, ePN_interface);
+	
+	/* Add external devices */
+	External_Process() ;
 
 	/* Match simultaneous for special processing */
 	{
@@ -224,3 +241,94 @@ void FS_devicefind(const char *code, struct parsedname *pn)
 		pn->selected_device = &UnknownDevice;
 	}
 }
+
+/* Need to lock struct global_namefind_struct since twalk requires global data -- can't pass void pointer */
+/* Except all *_detect routines are done sequentially, not concurrently */
+struct {
+	const struct family_node * f ;
+	int count ;
+} global_externalcount_struct;
+
+static void External_propertycount_action(const void *nodep, const VISIT which, const int depth)
+{
+	const struct property_node *p = *(struct property_node * const *) nodep;
+	(void) depth;
+
+	switch (which) {
+	case leaf:
+	case postorder:
+		if (strcmp(p->family, global_externalcount_struct.f->family) == 0 ) {
+			++global_externalcount_struct.count;
+		}
+	case preorder:
+	case endorder:
+		break;
+	}
+}
+
+static void External_propertycopy_action(const void *nodep, const VISIT which, const int depth)
+{
+	const struct property_node *p = *(struct property_node * const *) nodep;
+	(void) depth;
+
+	switch (which) {
+	case leaf:
+	case postorder:
+		if (strcmp(p->family, global_externalcount_struct.f->family) == 0 ) {
+			memcpy( 
+				& (global_externalcount_struct.f->dev.filetype_array[global_externalcount_struct.count]),
+				&(p->ft),
+				sizeof(struct filetype)
+			) ;
+			++global_externalcount_struct.count;
+		}
+	case preorder:
+	case endorder:
+		break;
+	}
+}
+
+// First loop through families -- to count properties and allocate filetype array.
+static void External_family_action(const void *nodep, const VISIT which, const int depth)
+{
+	const struct family_node *p = *(struct family_node * const *) nodep;
+	struct family_node * non_const_f ; // to allow assignments
+	(void) depth;
+ 
+ 	switch (which) {
+	case leaf:
+	case postorder:
+		// First count
+		global_externalcount_struct.f = p ;
+		global_externalcount_struct.count = 0 ;
+		twalk( property_tree, External_propertycount_action);
+		
+		// Refind this node to allow assignment
+		non_const_f = Find_External_Family( p->family ) ;
+		non_const_f->dev.filetype_array = owcalloc( 
+			global_externalcount_struct.count, 
+			sizeof( struct filetype) 
+		) ;
+		non_const_f->dev.count_of_filetypes = global_externalcount_struct.count ;
+		
+		// Next copy
+		global_externalcount_struct.count = 0 ;
+		twalk( property_tree, External_propertycopy_action);
+		
+		// Finally add to tree
+		Device2Tree( & (p->dev), ePN_real);
+		break ;
+	case preorder:
+	case endorder:
+		break;
+	}
+}
+
+static void External_Process(void)
+{
+	EXTERNALCOUNTLOCK;
+
+	twalk( family_tree, External_family_action);
+
+	EXTERNALCOUNTUNLOCK;
+}
