@@ -1,5 +1,5 @@
 /*
-$Id: ow_w1_bind.c,v 1.26 2012/09/28 20:43:34 alfille Exp $
+$Id$
 W1 Announce -- daemon  for showing w1 busmasters using Avahi
 Written 2008 Paul H Alfille
 email: paul.alfille@gmail.com
@@ -26,7 +26,7 @@ This file itself  is amodestly modified version of w1d by Evgeniy Polyakov
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <config.h>
