@@ -1,11 +1,10 @@
 /*
-$Id: ow_w1_select.c,v 1.20 2013/01/01 16:03:37 alfille Exp $
-W1 Announce -- daemon  for showing w1 busmasters using Avahi
-Written 2008 Paul H Alfille
-email: paul.alfille@gmail.com
-Released under the GPLv2
-Much thanks to Evgeniy Polyakov
-This file itself  is amodestly modified version of w1d by Evgeniy Polyakov
+	W1 Announce -- daemon  for showing w1 busmasters using Avahi
+	Written 2008 Paul H Alfille
+	email: paul.alfille@gmail.com
+	Released under the GPLv2
+	Much thanks to Evgeniy Polyakov
+	This file itself  is amodestly modified version of w1d by Evgeniy Polyakov
 */
 
 /*
@@ -26,7 +25,7 @@ This file itself  is amodestly modified version of w1d by Evgeniy Polyakov
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <config.h>
