@@ -1,9 +1,9 @@
 /*
-$Id: ow_devices.h,v 1.28 2012/11/30 02:07:23 alfille Exp $
+$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
-	email: palfille@earthlink.net
+	email: paul.alfille@gmail.com
 	Released under the GPL
 	See the header file: ow.h for full attribution
 	1wire/iButton system from Dallas Semiconductor
