@@ -1,5 +1,4 @@
 /*
-$Id$
     OW -- One-Wire filesystem
     version 0.4 7/2/2003
 
@@ -48,12 +47,13 @@ struct master_fake {
 	struct dirblob alarm;       /* alarm directory */
 };
 
+// DS2490R (usb) hub
 struct master_usb {
 #if OW_USB
-	struct usb_device *dev;
-	struct usb_dev_handle *usb;
-	int usb_bus_number;
-	int usb_dev_number;
+	libusb_device * lusb_dev ;
+	libusb_device_handle * lusb_handle ;
+	int bus_number;
+	int address;
 	int datasampleoffset;
 	int writeonelowtime;
 	int pulldownslewrate;
@@ -70,6 +70,7 @@ struct master_usb {
 	BYTE ds1420_address[SERIAL_NUMBER_SIZE];
 };
 
+// DS2482 (i2c) hub -- 800 has 8 channels
 struct master_i2c {
 	int channels;
 	int index;
@@ -83,6 +84,15 @@ struct master_i2c {
 	struct connection_in *head;
 };
 
+// HobbyBoards Master Hub
+// Single char channel (1,2,3,4,W -- ignore A)
+struct master_masterhub {
+	// Need to lock directory for "next" command"
+	int channels;
+	char channel_char;
+};
+
+// Embedded Data Systems HA7 hub
 struct master_ha7 {
 	ASCII lock[10];
 	int locked;
@@ -93,6 +103,20 @@ struct master_enet {
 	int version;
 };
 
+struct master_ds1wm {
+	off_t base ;
+	off_t page_start ;
+	off_t page_offset ;
+	void * mm ; // mmap
+	int longline ;
+	int byte_mode ;
+	long int frequency ;
+	int presence_mask ;
+	size_t mm_size ;
+	uint8_t channels_count; // for k1wm
+	uint8_t active_channel; // for k1wm
+};
+
 enum e_link_t_mode { e_link_t_unknown, e_link_t_extra, e_link_t_none } ;
 
 struct master_link {
@@ -100,6 +124,7 @@ struct master_link {
 	enum e_link_t_mode qmode ; //extra '?' after b command
 };
 
+// Embedded Data Systems HA5 hub
 struct master_ha5 {
 	int checksum ;              /* flag to use checksum byte in communication */
 	char channel ;
@@ -113,6 +138,7 @@ struct master_pbm {
 	struct connection_in *head;
 };
 
+// W1 (kernel) "device" 
 struct master_w1 {
 #if OW_W1
 	// bus master name kept in name
@@ -123,6 +149,7 @@ struct master_w1 {
 #endif /* OW_W1 */
 };
 
+// Search for W1 (kernel) devices
 struct master_w1_monitor {
 #if OW_W1
 	// netlink fd kept in file_descriptor
@@ -135,30 +162,43 @@ struct master_w1_monitor {
 #endif /* OW_W1 */
 };
 
+// Search for USB (DS9490R) devices
 struct master_usb_monitor {
 	FILE_DESCRIPTOR_OR_ERROR shutdown_pipe[2] ;
+	int usb_scan_interval ;
+
 };
 
 struct master_enet_monitor {
 	FILE_DESCRIPTOR_OR_ERROR shutdown_pipe[2] ;
+	int enet_scan_interval ;
+
+};
+
+// Search for HobbyBoards MasterHub (network) devices
+struct master_masterhub_monitor {
+	FILE_DESCRIPTOR_OR_ERROR shutdown_pipe[2] ;
+	int mh_scan_interval ;
+
 };
 
 struct master_browse {
 #if OW_ZERO
 	DNSServiceRef bonjour_browse;
-
-#if !OW_CYGWIN
-	AvahiServiceBrowser *avahi_browser ;
-	AvahiSimplePoll *avahi_poll ;
-	AvahiClient *avahi_client ;
-#if __HAS_IPV6__
-	char avahi_host[INET6_ADDRSTRLEN+1] ;
-#else
-	char avahi_host[INET_ADDRSTRLEN+1] ;
-#endif
-	char avahi_service[10] ;
-#endif							/* OW_CYGWIN */
 #endif /* OW_ZERO */
+
+#if OW_AVAHI
+	AvahiClient *client ;
+	AvahiServiceBrowser * browser ;
+	AvahiThreadedPoll *poll ;
+
+#if __HAS_IPV6__
+	char host[INET6_ADDRSTRLEN+1] ;
+#else
+	char host[INET_ADDRSTRLEN+1] ;
+#endif
+	char service[10] ;
+#endif	/* OW_AVAHI */
 };
 
 union master_union {
@@ -166,19 +206,22 @@ union master_union {
 	struct master_link link;
 	struct master_server server ;
 	struct master_usb usb;
+	struct master_usb_monitor usb_monitor ;
 	struct master_i2c i2c;
 	struct master_fake fake;
 	struct master_fake tester;
 	struct master_fake mock;
 	struct master_enet enet;
+	struct master_enet_monitor enet_monitor ;
 	struct master_ha5 ha5;
 	struct master_ha7 ha7;
 	struct master_pbm pbm;
 	struct master_w1 w1;
+	struct master_masterhub masterhub;
+	struct master_masterhub_monitor masterhub_monitor ;
 	struct master_w1_monitor w1_monitor ;
 	struct master_browse browse;
-	struct master_usb_monitor usb_monitor ;
-	struct master_enet_monitor enet_monitor ;
+	struct master_ds1wm ds1wm ;
 };
 
 
