@@ -1,9 +1,9 @@
 /*
-$Id: ow_stats.h,v 1.9 2009/12/12 02:10:16 alfille Exp $
+$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
-	email: palfille@earthlink.net
+	email: paul.alfille@gmail.com
 	Released under the GPL
 	See the header file: ow.h for full attribution
 	1wire/iButton system from Dallas Semiconductor
@@ -24,5 +24,6 @@ DeviceHeader(stats_write);
 DeviceHeader(stats_directory);
 DeviceHeader(stats_errors);
 DeviceHeader(stats_thread);
+DeviceHeader(stats_return_code);
 
 #endif							/* OW_STATS */
