@@ -1,4 +1,4 @@
-/* $Id$
+/* 
    Debug and error messages
    Meant to be included in ow.h
    Separated just for readability
@@ -16,25 +16,14 @@
 /* Debugging interface to showing all bus traffic
  * You need to configure compile with
  * ./configure --enable-owtraffic
+ * if you don't want empty functions
  * */
 
-/* Show bus traffic in detail (must be configured into the build) */
-#if OW_SHOW_TRAFFIC
-
+/* Show bus traffic in detail (must be configured into the build to be active) */
 void TrafficOut( const char * data_type, const BYTE * data, size_t length, const struct connection_in * in );
 void TrafficIn( const char * data_type, const BYTE * data, size_t length, const struct connection_in * in );
 
 void TrafficOutFD( const char * data_type, const BYTE * data, size_t length, FILE_DESCRIPTOR_OR_ERROR file_descriptor );
 void TrafficInFD( const char * data_type, const BYTE * data, size_t length, FILE_DESCRIPTOR_OR_ERROR file_descriptor );
 
-#else /* OW_SHOW_TRAFFIC */
-
-#define TrafficOut( data_type, data, length, in ) { } while (0)
-#define TrafficIn( data_type, data, length,  in ) { } while (0)
-
-#define TrafficOutFD( data_type, data, length, file_descriptor ) { } while (0)
-#define TrafficInFD( data_type, data, length,  file_descriptor ) { } while (0)
-
-#endif /* OW_SHOW_TRAFFIC */
-
 #endif							/* OW_TRAFFIC_H */
