@@ -1,5 +1,5 @@
 /*
-$Id: ow_w1.h,v 1.29 2010/08/08 20:18:51 alfille Exp $
+$Id$
 W! Announce -- daemon  for showing w1 busmasters using Avahi
 Written 2008 Paul H Alfille
 email: paul.alfille@gmail.com
@@ -40,7 +40,7 @@ enum Netlink_Read_Status {
 struct connection_in ;
 struct parsedname ;
 
-void w1_bind( void ) ;
+GOOD_OR_BAD w1_bind( struct connection_in * in ) ;
 
 void RemoveW1Bus( int bus_master ) ;
 void AddW1Bus( int bus_master ) ;
@@ -61,15 +61,15 @@ struct netlink_parse {
 	struct w1_netlink_cmd *	w1c ;
 	unsigned char *		data ;
 	int			data_size ;
+	__u8		follow[0] ;
 } ;
 
 //void * w1_master_command(struct netlink_parse * nlp) ;
 void * w1_master_command(void * v) ;
 
 void w1_parse_master_list(struct netlink_parse * nlp);
-void Netlink_Parse_Destroy( struct netlink_parse * nlp ) ;
 GOOD_OR_BAD Netlink_Parse_Get( struct netlink_parse * nlp ) ;
-GOOD_OR_BAD Get_and_Parse_Pipe( FILE_DESCRIPTOR_OR_ERROR file_descriptor, struct netlink_parse * nlp ) ;
+GOOD_OR_BAD Netlink_Parse_Buffer( struct netlink_parse * nlp ) ;
 void Netlink_Print( struct nlmsghdr * nlm, struct cn_msg * cn, struct w1_netlink_msg * w1m, struct w1_netlink_cmd * w1c, unsigned char * data, int length ) ;
 enum Netlink_Read_Status W1_Process_Response( void (* nrs_callback)( struct netlink_parse * nlp, void  *v, const struct parsedname * pn), SEQ_OR_ERROR seq, void * v, const struct parsedname * pn ) ;
 
