@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -14,19 +13,14 @@ $Id$
 #include "ow.h"
 #include "ow_server.h"
 
-/* Globalss for port and bus communication */
+/* Globals for port and bus communication */
 /* connections globals stored in ow_connect.c */
 /* i.e. connection_in * head_inbound_list ...         */
 
 /* State information, sent to remote or kept locally */
-/* cacheenabled, presencecheck, tempscale, devform */
-#if OW_CACHE
+/* presencecheck, tempscale, devform */
 int32_t SemiGlobal = ((uint8_t) fdi) << 24 | ((uint8_t) temp_celsius) << 16 | ((uint8_t) 1)
 	<< 8 | ((uint8_t) 1);
-#else
-int32_t SemiGlobal = ((uint8_t) fdi) << 24 | ((uint8_t) temp_celsius) << 16 | ((uint8_t) 1)
-	<< 8;
-#endif
 
 struct global Globals = {
 #if OW_ZERO
@@ -34,10 +28,8 @@ struct global Globals = {
 #endif
 
 	.progname = NULL,			// "One Wire File System" , Can't allocate here since it's freed
-	.now_background = 0,
 
 	.error_level = e_err_default,
-	.error_print = e_err_print_mixed,
 
 	.readonly = 0,
 };
