@@ -1,5 +1,4 @@
 /*
-$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
@@ -174,8 +173,11 @@ static void BrowseBack(DNSServiceRef s, DNSServiceFlags f, uint32_t i,
 						}
 					}
 					DNSServiceRefDeallocate(sr);
-					if (err == kDNSServiceErr_NoError)
+					if (err == kDNSServiceErr_NoError) {
+						// Successful exit
+						CONNIN_WUNLOCK;
 						return;
+					}
 				}
 			}
 			BSKill(bs);
@@ -187,11 +189,12 @@ static void BrowseBack(DNSServiceRef s, DNSServiceFlags f, uint32_t i,
 
 void OW_Browse(void)
 {
-	struct RefStruct *rs;
+	struct RefStruct *rs = malloc(sizeof(struct RefStruct));
 	DNSServiceErrorType dnserr;
 
-	if ((rs = malloc(sizeof(struct RefStruct))) == NULL)
+	if ( rs == NULL) {
 		return;
+	}
 
 	dnserr = DNSServiceBrowse(&Globals.browse, 0, 0, "_owserver._tcp", NULL, BrowseBack, NULL);
 	rs->sref = Globals.browse;
@@ -202,9 +205,11 @@ void OW_Browse(void)
 		err = pthread_create(&thread, 0, Process, (void *) rs);
 		if (err) {
 			ERROR_CONNECT("Zeroconf/Bounjour browsing thread error %d).\n", err);
+			free(rs) ;
 		}
 	} else {
 		LEVEL_CONNECT("DNSServiceBrowse error = %d\n", dnserr);
+		free( rs ) ;
 	}
 }
 
