@@ -1,9 +1,9 @@
 /*
-$Id: ownet_setget.c,v 1.4 2012/12/22 21:41:07 alfille Exp $
+$Id$
     OWFS -- One-Wire filesystem
     OWHTTPD -- One-Wire Web Server
     Written 2003 Paul H Alfille
-    email: palfille@earthlink.net
+    email: paul.alfille@gmail.com
     Released under the GPL
     See the header file: ow.h for full attribution
     1wire/iButton system from Dallas Semiconductor
@@ -92,3 +92,14 @@ const char *OWNET_get_device_format(void)
 		return "f.i";
 	}
 }
+
+void OWNET_set_trim( int trim_state )
+{
+	ow_Global.control_flags &= ~TRIM ; // clear trim
+	ow_Global.control_flags |= trim_state ? TRIM : 0 ;
+}
+
+int OWNET_get_trim( void )
+{
+	return (ow_Global.control_flags & TRIM) != 0 ;
+}
