@@ -1,5 +1,5 @@
 /*
-$Id: handler.c,v 1.42 2012/03/27 17:34:27 alfille Exp $
+$Id$
     OW_HTML -- OWFS used for the web
     OW -- One-Wire filesystem
 
@@ -18,7 +18,7 @@ $Id: handler.c,v 1.42 2012/03/27 17:34:27 alfille Exp $
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* owserver -- responds to requests over a network socket, and processes them on the 1-wire bus/
@@ -41,8 +41,6 @@ $Id: handler.c,v 1.42 2012/03/27 17:34:27 alfille Exp $
 int persistent_connections = 0;
 int handler_count = 0 ;
 
-#if OW_MT						// Handler for multithreaded approach -- with ping
-
 static void SingleHandler(struct handlerdata *hd);
 
 /*
@@ -164,23 +162,16 @@ static void SingleHandler(struct handlerdata *hd)
 	PingLoop( hd ) ;
 
 	if (hd->sp.path) {
-		owfree(hd->sp.path);
+#if ( __GNUC__ > 4 ) || (__GNUC__ == 4 && __GNUC_MINOR__ > 4 )
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcast-qual"
+	// allocated in From_Client with owmalloc, but cast to const
+		owfree( (void *) hd->sp.path);
+#pragma GCC diagnostic pop
+#else
+	// allocated in From_Client with owmalloc, but cast to const
+		owfree( (void *) hd->sp.path);
+#endif
 		hd->sp.path = NULL;
 	}
 }
-
-#else							/* no OW_MT */
-void Handler(FILE_DESCRIPTOR_OR_ERROR file_descriptor)
-{
-	struct handlerdata hd;
-	hd.file_descriptor = file_descriptor;
-	if (FromClient(&hd) == 0) {
-		DataHandler(&hd);
-	}
-	if (hd.sp.path) {
-		owfree(hd.sp.path);
-		hd.sp.path = NULL;
-	}
-}
-
-#endif							/* OW_MT */
