@@ -1,5 +1,5 @@
 /*
-$Id: read.c,v 1.29 2011/12/07 03:50:12 alfille Exp $
+$Id$
     OW_HTML -- OWFS used for the web
     OW -- One-Wire filesystem
 
@@ -18,7 +18,7 @@ $Id: read.c,v 1.29 2011/12/07 03:50:12 alfille Exp $
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* owserver -- responds to requests over a network socket, and processes them on the 1-wire bus/
