@@ -1,5 +1,5 @@
 /*
-$Id: write.c,v 1.11 2010/01/25 16:08:31 alfille Exp $
+$Id$
     OW_HTML -- OWFS used for the web
     OW -- One-Wire filesystem
 
@@ -18,7 +18,7 @@ $Id: write.c,v 1.11 2010/01/25 16:08:31 alfille Exp $
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* owserver -- responds to requests over a network socket, and processes them on the 1-wire bus/
@@ -42,7 +42,6 @@ $Id: write.c,v 1.11 2010/01/25 16:08:31 alfille Exp $
 /* sm has been read, cm has been zeroed */
 /* pn is configured */
 /* data is what will be written, of sm->size length */
-/* Read, will return: */
 /* cm fully constructed */
 /* cm.ret is also set to an error <0 or the written length */
 void WriteHandler(struct handlerdata *hd, struct client_msg *cm, struct one_wire_query *owq)
