@@ -2,7 +2,7 @@
 
 """
 ::BOH
-$Id: temperature.py,v 1.2 2005/01/20 06:44:30 peterk Exp $
+$Id$
 
 Copyright (c) 2004 Peter Kropf. All rights reserved.
 
@@ -18,7 +18,7 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 ::EOH
 
 Find all temperature sensors (DS18S20) and print out their current
