@@ -2,7 +2,7 @@
 
 """
 ::BOH
-$Id: tree.py,v 1.3 2007/05/22 18:25:53 alfille Exp $
+$Id$
 
 Copyright (c) 2004 Peter Kropf. All rights reserved.
 
@@ -18,7 +18,7 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 ::EOH
 
 Print the address and type of all sensors on a 1-wire network.
